@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@
 #endif
 
 #include "BarShader.h"                      // Module's Prototype(s) - audited 5 Nov 2004
-#include "wintypes.h"                       // DWORD - audited 4 Nov 2004
+#include "wintypes.h"                       // x::DWORD - audited 4 Nov 2004
 #include "xmule.h"                          // theApp - audited 4 Nov 2004
 
 #include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
@@ -120,7 +120,7 @@ void CBarShader::SetFileSize(uint32_t fileSize)
     }
 }
 
-void CBarShader::FillRange(uint32_t start, uint32_t end, DWORD color)
+void CBarShader::FillRange(uint32_t start, uint32_t end, x::DWORD color)
 {
     if (end > m_uFileSize)
     {
@@ -194,7 +194,7 @@ void CBarShader::FillRange(uint32_t start, uint32_t end, DWORD color)
     bsNew->DeleteUpTo(bsEnd);
 }
 
-void CBarShader::Fill(DWORD color)
+void CBarShader::Fill(x::DWORD color)
 {
     m_FirstSpan->DeleteUpTo(NULL);
     m_FirstSpan->start = 0;
@@ -205,7 +205,7 @@ void CBarShader::Fill(DWORD color)
 void CBarShader::Draw(wxDC *dc, int iLeft, int iTop, bool bFlat)
 {
     BarSpan *bsCurrent = m_FirstSpan;
-    RECT rectSpan;
+    x::RECT rectSpan;
     rectSpan.top = iTop;
     rectSpan.bottom = iTop + m_iHeight;
     rectSpan.right = iLeft;
@@ -258,7 +258,7 @@ void CBarShader::Draw(wxDC *dc, int iLeft, int iTop, bool bFlat)
     ///printf(" piirettiin %d palaa. Kesti %d ms. Leveys %d\n",drawnItems,GetTickCount()-now,m_iWidth);
 }
 
-void CBarShader::FillRect(wxDC *dc, RECT *rectSpan, DWORD color, bool bFlat)
+void CBarShader::FillRect(wxDC *dc, x::RECT *rectSpan, x::DWORD color, bool bFlat)
 {
     if (rectSpan->right - rectSpan->left < 1)
     return;
@@ -277,7 +277,7 @@ void CBarShader::FillRect(wxDC *dc, RECT *rectSpan, DWORD color, bool bFlat)
     }
 }
 
-void CBarShader::FillRect(wxDC *dc, RECT *rectSpan, float fRed, float fGreen,
+void CBarShader::FillRect(wxDC *dc, x::RECT *rectSpan, float fRed, float fGreen,
 float fBlue, bool bFlat)
 {
     if (rectSpan->right - rectSpan->left < 1)
@@ -295,8 +295,8 @@ float fBlue, bool bFlat)
     {
         if (m_Modifiers == NULL || m_used3dlevel != theApp.dynprefs->Get<long>("progress-bar-style"))
         BuildModifiers();
-        RECT rect;
-        memcpy( &rect, rectSpan, sizeof(RECT));
+        x::RECT rect;
+        memcpy( &rect, rectSpan, sizeof(x::RECT));
         int iTop = rect.top;
         int iBot = rect.bottom;
         int iMax = HALF(m_iHeight);
