@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 #ifndef BARSHADER_H
 #define BARSHADER_H
 
-#include "wintypes.h"                       // DWORD - audited 4 Nov 2004
+#include "wintypes.h"                       // x::DWORD - audited 4 Nov 2004
 
 #include <stdint.h>                         // uint32_t
 #include <wx/dc.h>
@@ -73,18 +73,18 @@ public:
     void SetFileSize(uint32_t fileSize);
 
     //fills in a range with a certain color, new ranges overwrite old
-    void FillRange(uint32_t start, uint32_t end, DWORD color);
+    void FillRange(uint32_t start, uint32_t end, x::DWORD color);
 
     //fills in entire range with a certain color
-    void Fill(DWORD color);
+    void Fill(x::DWORD color);
 
     //draws the bar
     void Draw(wxDC* dc, int iLeft, int iTop, bool bFlat);
 
 protected:
     void BuildModifiers();
-    void FillRect(wxDC* dc, RECT* rectSpan, float fRed, float fGreen, float fBlue, bool bFlat);
-    void FillRect(wxDC* dc, RECT* rectSpan, DWORD color, bool bFlat);
+    void FillRect(wxDC* dc, x::RECT* rectSpan, float fRed, float fGreen, float fBlue, bool bFlat);
+    void FillRect(wxDC* dc, x::RECT* rectSpan, x::DWORD color, bool bFlat);
     void SetScaling(void);
 
     int    m_iWidth;
@@ -98,10 +98,10 @@ private:
     {
         uint32_t start;
         uint32_t end;
-        DWORD color;
+        x::DWORD color;
         BarSpan *next;
 
-        BarSpan(uint32_t s, uint32_t e, DWORD cr = RGB(0, 0, 0))
+        BarSpan(uint32_t s, uint32_t e, x::DWORD cr = RGB(0, 0, 0))
         {
             start = s;
             end = e;
@@ -109,7 +109,7 @@ private:
             next = NULL;
         }
 
-        BarSpan(BarSpan* prev, uint32_t s, uint32_t e, DWORD cr)
+        BarSpan(BarSpan* prev, uint32_t s, uint32_t e, x::DWORD cr)
         {
             start = s;
             end = e;
