@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 //Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -268,7 +268,7 @@ CUpDownClient::~CUpDownClient()
 
 bool CUpDownClient::ProcessHelloPacket(char *pachPacket, uint32_t nSize)
 {
-    CSafeMemFile data((BYTE *) pachPacket, nSize);
+    CSafeMemFile data((x::BYTE *) pachPacket, nSize);
     uint8_t hashsize;
     if (1 == data.Read( &hashsize, 1))
     {
@@ -282,7 +282,7 @@ bool CUpDownClient::ProcessHelloPacket(char *pachPacket, uint32_t nSize)
 
 bool CUpDownClient::ProcessHelloAnswer(char *pachPacket, uint32_t nSize)
 {
-    CSafeMemFile data((BYTE *) pachPacket, nSize);
+    CSafeMemFile data((x::BYTE *) pachPacket, nSize);
     return ProcessHelloTypePacket( &data);
 }
 
@@ -290,7 +290,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CSafeMemFile *data)
 {
     m_bIsHybrid = false;
     m_bIsML = false;
-    DWORD dwEmuleTags = 0;
+    x::DWORD dwEmuleTags = 0;
     if (data->Read( &m_achUserHash, 16) == 16)
     {
         uint32_t nUserID;
@@ -674,7 +674,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
 
 void CUpDownClient::ProcessMuleInfoPacket(char *pachPacket, uint32_t nSize)
 {
-    CSafeMemFile *data = new CSafeMemFile((BYTE *) pachPacket, nSize);
+    CSafeMemFile *data = new CSafeMemFile((x::BYTE *) pachPacket, nSize);
     //The version number part of this packet will soon be useless since it is only able to go to v.99.
     //Why the version is a uint8_t and why it was not done as a tag like the eDonkey hello packet is not known..
     //Therefore, sooner or later, we are going to have to switch over to using the eDonkey hello packet to
@@ -934,7 +934,7 @@ void CUpDownClient::ProcessMuleCommentPacket(char *pachPacket, uint32_t nSize)
             unsigned int length;
             if (nSize > (sizeof(m_iRate) + sizeof(length) - 1))
             {
-                CSafeMemFile data((BYTE *) pachPacket, nSize);
+                CSafeMemFile data((x::BYTE *) pachPacket, nSize);
                 if (sizeof(m_iRate) == data.Read( &m_iRate, sizeof(m_iRate)))
                 {
                     if (sizeof(length) == data.Read( &length, sizeof(length)))
@@ -1710,7 +1710,7 @@ void CUpDownClient::InfoPacketsReceived()
  wxASSERT (false);
  return;
  }
- BYTE* abyResultBuffer = NULL;
+ x::BYTE* abyResultBuffer = NULL;
  long nResultSize = 0;
  if (!cur_frame->Encode(abyResultBuffer, nResultSize, CXIMAGE_FORMAT_PNG)) {
  wxASSERT (false);
@@ -1742,7 +1742,7 @@ void CUpDownClient::InfoPacketsReceived()
  if (!m_bPreviewReqPending)
  return;
  m_bPreviewReqPending = false;
- CSafeMemFile data((BYTE*) pachPacket,nSize);
+ CSafeMemFile data((x::BYTE*) pachPacket,nSize);
  unsigned char Hash[16];
  data.Read(Hash,16);
  uint8_t nCount;
@@ -1760,7 +1760,7 @@ void CUpDownClient::InfoPacketsReceived()
  for (int i = 0; i != nCount; i++) {
  long nSize;
  data.Read(&nSize,4);
- BYTE* pBuffer = new BYTE[nSize];
+ x::BYTE* pBuffer = new BYTE[nSize];
  data.Read(pBuffer,nSize);
  CxImage* image = new CxImage(pBuffer, nSize,CXIMAGE_FORMAT_PNG);
  delete[] pBuffer;
