@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -48,7 +48,7 @@ protected:
     DECLARE_MESSAGE_MAP()
     virtual bool OnInitDialog(); 
     afx_msg void OnBnClickedCsend();
-    void	OnShowWindow(bool bShow,UINT nStatus);
+    void	OnShowWindow(bool bShow,x::UINT nStatus);
     virtual bool	PreTranslateMessage(MSG* pMsg);
 public:
     afx_msg void OnBnClickedCclose();
