@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 // 
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 // 
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -31,7 +31,7 @@
 #include "otherfunctions.h"                 // Needed for md4cpy - audited 4 Nov 2004
 #include "resource.h"                       // Needed for IDS_ERR_CREDITFILEOLD - audited 4 Nov 2004
 #include "sockets.h"                        // Needed for CServerConnect - audited 5 Nov 2004
-#include "wintypes.h"                       // Needed for BYTE - audited 5 Nov 2004
+#include "wintypes.h"                       // Needed for x::BYTE - audited 5 Nov 2004
 #include "xmule.h"                          // Needed for theApp - audited 4 Nov 2004
 #include "xmuleDlg.h"                       // Needed for theApp.xmuledlg - audited 4 Nov 2004
 
@@ -356,7 +356,7 @@ void CClientCreditsList::SaveList()
 
     if (savelist && (savelist.good() == true))
     {
-        BYTE* pBuffer = new BYTE[MapData_GetCount(mcc) * sizeof(CreditStruct)];
+        x::BYTE* pBuffer = new x::BYTE[MapData_GetCount(mcc) * sizeof(CreditStruct)];
         uint32_t count = 0;
         CClientCredits* cur_client;
         MAP* pos;
