@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -86,8 +86,8 @@ END_EVENT_TABLE()
 
 #if 0
 /////////////////////////////////////////////////////////////////////////////
-bool CColorFrameCtrl::Create(DWORD dwStyle, const RECT &rect,
-CWnd *pParentWnd, UINT nID)
+bool CColorFrameCtrl::Create(x::DWORD dwStyle, const x::RECT &rect,
+CWnd *pParentWnd, x::UINT nID)
 {
     bool result;
     static wxString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
@@ -104,7 +104,7 @@ CWnd *pParentWnd, UINT nID)
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
-void CColorFrameCtrl::SetFrameColor(COLORREF color)
+void CColorFrameCtrl::SetFrameColor(x::COLORREF color)
 {
     m_crFrameColor = color;
     //m_brushFrame.DeleteObject() ;
@@ -119,7 +119,7 @@ void CColorFrameCtrl::SetFrameColor(COLORREF color)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void CColorFrameCtrl::SetBackgroundColor(COLORREF color)
+void CColorFrameCtrl::SetBackgroundColor(x::COLORREF color)
 {
     m_crBackColor = color;
     //m_brushBack.DeleteObject() ;
