@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 #ifndef __ColorFrameCtrl_H__
 #define __ColorFrameCtrl_H__
 
-#include "wintypes.h"                       // COLORREF - audited 4 Nov 2004
+#include "wintypes.h"                       // x::COLORREF - audited 4 Nov 2004
 
 #include <wx/brush.h>
 #ifndef RGB
@@ -38,13 +38,13 @@ public:
     CColorFrameCtrl( wxWindow* parent, int id,int wid,int hei );
 
 public:
-    void SetFrameColor(COLORREF color);
-    void SetBackgroundColor(COLORREF color);
+    void SetFrameColor(x::COLORREF color);
+    void SetBackgroundColor(x::COLORREF color);
 
 // Implementation
 public:
-    COLORREF m_crBackColor;        // background color
-    COLORREF m_crFrameColor;       // frame color
+    x::COLORREF m_crBackColor;        // background color
+    x::COLORREF m_crFrameColor;       // frame color
 
     virtual ~CColorFrameCtrl();
 
