@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -55,11 +55,11 @@ CBarShader CUpDownClient::s_StatusBar(16);
 
 void CUpDownClient::DrawStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
-    DWORD crBoth;
-    DWORD crNeither;
-    DWORD crClientOnly;
-    DWORD crPending;
-    DWORD crNextPending;
+    x::DWORD crBoth;
+    x::DWORD crNeither;
+    x::DWORD crClientOnly;
+    x::DWORD crPending;
+    x::DWORD crNextPending;
     if (bFlat)
     {
         crBoth = RGB(0, 150, 0);
@@ -162,7 +162,7 @@ void CUpDownClient::AskForDownload()
 
 bool CUpDownClient::IsSourceRequestAllowed()
 {
-    DWORD dwTickCount =::GetTickCount() + CONNECTION_LATENCY;
+    x::DWORD dwTickCount =::GetTickCount() + CONNECTION_LATENCY;
     int nTimePassedClient = dwTickCount - GetLastSrcAnswerTime();
     int nTimePassedFile = dwTickCount - reqfile->GetLastAnsweredTime();
     bool bNeverAskedBefore = GetLastSrcReqTime() == 0;
@@ -246,7 +246,7 @@ void CUpDownClient::SendFileRequest()
 
 void CUpDownClient::ProcessFileInfo(char *packet, uint32_t size)
 {
-    CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+    CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
     unsigned char cfilehash[16];
     data->Read(cfilehash, 16);
     uint16_t namelength;
@@ -264,7 +264,7 @@ void CUpDownClient::ProcessFileInfo(char *packet, uint32_t size)
 
 void CUpDownClient::ProcessFileStatus(char *packet, uint32_t size)
 {
-    CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+    CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
     unsigned char cfilehash[16];
     data->Read(cfilehash, 16);
     if ((reqfile) && (! memcmp(cfilehash, reqfile->GetFileHash(), 16)))
@@ -431,7 +431,7 @@ void CUpDownClient::ProcessHashSet(unsigned char *packet, uint32_t size)
         if (m_bHashsetRequested)
         {
             m_bHashsetRequested = false;
-            CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+            CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
             if (reqfile->LoadHashsetFromFile(data, true))
             {
                 SetDownloadState(DS_ONQUEUE);
@@ -536,7 +536,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32_t size, bool packed)
     // Update stats
     m_dwLastBlockReceived =::GetTickCount();
     // Read data from packet
-    CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+    CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
     unsigned char fileID[16];
     data->Read(fileID, 16);
     // Check that this data is for the correct file
@@ -589,7 +589,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32_t size, bool packed)
                     {
                         // Write to disk (will be buffered in part file class)
                         lenWritten = reqfile->WriteToBuffer(size - HEADER_SIZE,
-                        (BYTE *)(packet + HEADER_SIZE),
+                        (x::BYTE *)(packet + HEADER_SIZE),
                         nStartPos,
                         nEndPos,
                         cur_block->block);
@@ -602,9 +602,9 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32_t size, bool packed)
                         // Don't get too big
                         if (lenUnzipped > (GAPBLOCKSIZE + 300))
                         lenUnzipped = (GAPBLOCKSIZE + 300);
-                        BYTE *unzipped = new BYTE[lenUnzipped];
+                        x::BYTE *unzipped = new x::BYTE[lenUnzipped];
                         // Try to unzip the packet
-                        int result = unzip(cur_block, (BYTE *)(packet + HEADER_SIZE), (size - HEADER_SIZE), &unzipped, &lenUnzipped);
+                        int result = unzip(cur_block, (x::BYTE *)(packet + HEADER_SIZE), (size - HEADER_SIZE), &unzipped, &lenUnzipped);
                         if (result == Z_OK)
                         {
                             // Write any unzipped data to disk
@@ -687,7 +687,7 @@ void CUpDownClient::ProcessBlockPacket(char *packet, uint32_t size, bool packed)
     }
 }
 
-int CUpDownClient::unzip(Pending_Block_Struct *block, BYTE *zipped, uint32_t lenZipped, BYTE **unzipped, uint32_t *lenUnzipped, bool recursive)
+int CUpDownClient::unzip(Pending_Block_Struct *block, x::BYTE *zipped, uint32_t lenZipped, x::BYTE **unzipped, uint32_t *lenUnzipped, bool recursive)
 {
     int err = Z_DATA_ERROR;
     try
@@ -742,7 +742,7 @@ int CUpDownClient::unzip(Pending_Block_Struct *block, BYTE *zipped, uint32_t len
             if (newLength == 0)
             newLength = lenZipped *2;
             // Copy any data that was successfully unzipped to new array
-            BYTE *temp = new BYTE[newLength];
+            x::BYTE *temp = new x::BYTE[newLength];
             memcpy(temp, ( *unzipped), (zS->total_out - block->totalUnzipped));
             delete [] ( *unzipped);
             ( *unzipped) = temp;
@@ -873,8 +873,20 @@ void CUpDownClient::ShowDownloadingParts(wxString &partsYN)
 {
     Requested_Block_Struct *cur_block;
     unsigned int x;
-    partsYN.Alloc(m_nPartCount + 1);
-    for (x = 0; x <= m_nPartCount; x++) partsYN.SetChar(x, 'N');
+    // Bug found + fixed by Uri on 18 May 2005
+    // Start Fix
+    {
+      bool allocateSuccess = partsYN.Alloc(m_nPartCount + 1);
+      assert(allocateSuccess);
+    }
+
+    partsYN.Empty();
+    for (x = 0; x <= m_nPartCount; ++x)
+    {
+       partsYN.Append('N');
+    }
+    // End Fix
+    
     for (POSITION pos = m_PendingBlocks_list.GetHeadPosition(); pos != 0; m_PendingBlocks_list.GetNext(pos))
     {
         cur_block = m_PendingBlocks_list.GetAt(pos)->block;
@@ -893,7 +905,7 @@ void CUpDownClient::ShowDownloadingParts(wxString &partsYN)
 
 void CUpDownClient::UpdateDisplayedInfo(bool force)
 {
-    DWORD curTick =::GetTickCount();
+    x::DWORD curTick =::GetTickCount();
     if (force || curTick - m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE + (uint32_t)(rand() / (RAND_MAX/1000)))
     {
         theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
