@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -21,34 +21,36 @@
 
 #ifdef PRECOMP
 #	include "xmule-headers.h"
-#else
-#	include "DownloadListCtrl.h"
-
-#	include "ChatWnd.h"
-#	include "ClientDetailDialog.h"
-#	include "CommentDialogLst.h"
-#	include "config.h"
-#	include "DownloadQueue.h"
-#	include "FileDetailDialog.h"
-#	include "FriendList.h"
-#	include "muuli_wdr.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#	include "PartFile.h"
-#include "Preferences.h"                    // CPreferences::List Settings
-#	include "TransferWnd.h"
-#	include "updownclient.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
 #endif
 
+#include "DownloadListCtrl.h"
+#include "ChatWnd.h"
+#include "ClientDetailDialog.h"
+#include "CommentDialogLst.h"
+#include "config.h"
+#include "DownloadQueue.h"
+#include "FileDetailDialog.h"
+#include "FriendList.h"
+#include "muuli_wdr.h"
+#include "opcodes.h"
+#include "otherfunctions.h"
+#include "PartFile.h"
+#include "Preferences.h"                    // CPreferences::List Settings
+#include "TransferWnd.h"
+#include "updownclient.h"
+#include "wintypes.h"
+#include "xmule.h"
+#include "xmuleDlg.h"
+
+
 #include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
 #include <arpa/inet.h>
 #include <cmath>                            // std::min
 #include <iostream>
+#include <wx/menu.h>                        // wxMenu
 #include <wx/msgdlg.h>                      // wxMessageBox
+#include <wx/stattext.h>                    // wxStaticText
 #include <wx/textdlg.h>                     // wxTextEntryDialog
 
 using std::cout;
@@ -134,7 +136,7 @@ struct CtrlItem_Struct
     CPartFile*       owner;
     void*            value;
     CtrlItem_Struct* parent;
-    DWORD            dwUpdated;
+    x::DWORD            dwUpdated;
     wxBitmap*        status;
 
     ~CtrlItem_Struct()
@@ -582,9 +584,9 @@ void CDownloadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const
         }
     }
  /*else if (content->type != 1) {
- COLORREF crHighlight = m_crWindowText;
- COLORREF crWindow = m_crWindow;
- COLORREF crHalf = DLC_RGBBLEND(crHighlight, crWindow, 16);
+ x::COLORREF crHighlight = m_crWindowText;
+ x::COLORREF crWindow = m_crWindow;
+ x::COLORREF crHalf = DLC_RGBBLEND(crHighlight, crWindow, 16);
  odc->SetBkColor(crHalf);
     } */
     else
@@ -634,7 +636,7 @@ void CDownloadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const
     // lagloose
     dc->SetPen( *wxTRANSPARENT_PEN);
     // }
-    RECT cur_rec;
+    x::RECT cur_rec;
     int tree_start = 0, tree_end = 0;
     bool notLast = item + 1 != GetItemCount();
     bool notFirst = item != 0;
@@ -744,7 +746,7 @@ void CDownloadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const
     if (tree_start < tree_end)
     {
         //set new bounds
-        RECT tree_rect;
+        x::RECT tree_rect;
         //lpDrawItemStruct->rcItem.top;:
         tree_rect.top = rect.y;
         //lpDrawItemStruct->rcItem.bottom;:
@@ -783,7 +785,7 @@ void CDownloadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const
         else if(isOpenRoot)
         {
             //draw circle
-            RECT circle_rec;
+            x::RECT circle_rec;
             //COLORREF crBk = dc->GetBkColor();
             wxColour crBk = dc->GetBackground() .GetColour();
             circle_rec.top = middle - 2;
@@ -1072,7 +1074,7 @@ void CDownloadListCtrl::UpdateItem(void *toupdate)
     }
 }
 
-void CDownloadListCtrl::DrawFileItem(wxDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem)
+void CDownloadListCtrl::DrawFileItem(wxDC *dc, int nColumn, x::LPRECT lpRect, CtrlItem_Struct *lpCtrlItem)
 {
     if (lpRect->left < lpRect->right)
     {
@@ -1096,7 +1098,7 @@ void CDownloadListCtrl::DrawFileItem(wxDC *dc, int nColumn, LPRECT lpRect, CtrlI
                         }
                     }
                     // it's already centered by OnDrawItem() ...
-                    POINT point =
+                    x::POINT point =
                     {
     lpRect->left - 4, lpRect->top /*+3 */
                                         };
@@ -1151,7 +1153,7 @@ void CDownloadListCtrl::DrawFileItem(wxDC *dc, int nColumn, LPRECT lpRect, CtrlI
                 int iWidth = lpRect->right - lpRect->left;
                 int iHeight = lpRect->bottom - lpRect->top;
                 // DO NOT DRAW IT ALL THE TIME
-                DWORD dwTicks = GetTickCount();
+                x::DWORD dwTicks = GetTickCount();
                 wxMemoryDC cdcStatus;
                 if (lpCtrlItem->dwUpdated + DLC_BARUPDATE < dwTicks || !lpCtrlItem->status || iWidth != lpCtrlItem->status->GetWidth() || !lpCtrlItem->dwUpdated)
                 {
@@ -1309,7 +1311,7 @@ void CDownloadListCtrl::DrawFileItem(wxDC *dc, int nColumn, LPRECT lpRect, CtrlI
 
 #define ILD_NORMAL wxIMAGELIST_DRAW_TRANSPARENT
 
-void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem)
+void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, x::LPRECT lpRect, CtrlItem_Struct *lpCtrlItem)
 {
     if (lpRect->left < lpRect->right)
     {
@@ -1322,10 +1324,10 @@ void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, LPRECT lpRect, Ctr
             // icon, name, status:
         case 0:
             {
-                RECT cur_rec;
-                memcpy( &cur_rec, lpRect, sizeof(RECT));
+                x::RECT cur_rec;
+                memcpy( &cur_rec, lpRect, sizeof(x::RECT));
                 // +3 is added by OnDrawItem()... so take it off
-                POINT point =
+                x::POINT point =
                 {
     cur_rec.left, cur_rec.top /*+1 */
                     - 2
@@ -1379,7 +1381,7 @@ void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, LPRECT lpRect, Ctr
                 cur_rec.left += 20;
                 if (lpUpDownClient->IsFriend())
                 {
-                    POINT point2 =
+                    x::POINT point2 =
                     {
                         cur_rec.left, cur_rec.top + 1
                                         };
@@ -1388,7 +1390,7 @@ void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, LPRECT lpRect, Ctr
                 }
                 else if(lpUpDownClient->ExtProtocolAvailable())
                 {
-                    POINT point2 =
+                    x::POINT point2 =
                     {
                         cur_rec.left, cur_rec.top + 1
                                         };
@@ -1397,7 +1399,7 @@ void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, LPRECT lpRect, Ctr
                 }
                 else
                 {
-                    POINT point2 =
+                    x::POINT point2 =
                     {
                         cur_rec.left, cur_rec.top + 1
                                         };
@@ -1468,7 +1470,7 @@ void CDownloadListCtrl::DrawSourceItem(wxDC *dc, int nColumn, LPRECT lpRect, Ctr
                 lpRect->top++;
                 int iWidth = lpRect->right - lpRect->left;
                 int iHeight = lpRect->bottom - lpRect->top;
-                DWORD dwTicks = GetTickCount();
+                x::DWORD dwTicks = GetTickCount();
                 wxMemoryDC cdcStatus;
                 if (lpCtrlItem->dwUpdated + (4 *DLC_BARUPDATE) < dwTicks || !lpCtrlItem->status || iWidth != lpCtrlItem->status->GetWidth() || !lpCtrlItem->dwUpdated)
                 {
@@ -1708,7 +1710,7 @@ bool CDownloadListCtrl::ProcessEvent(wxEvent &evt)
     if (item != (-1))
     {
         CtrlItem_Struct *content = (CtrlItem_Struct *) this->GetItemData(item);
-        UINT selectedCount = this->GetSelectedItemCount();
+        x::UINT selectedCount = this->GetSelectedItemCount();
         CTypedPtrList < CPtrList, CPartFile *> selectedList;
         item =-1;
         for ( ; ;)
