@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -57,7 +57,7 @@ public:
 	void	RemoveFile(CPartFile* toremove);
 	void	ClearCompleted();
 	//virtual bool OnCommand(WPARAM wParam,LPARAM lParam );
-	//virtual bool Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID);
+	//virtual bool Create(x::DWORD dwStyle, const x::RECT& rect, CWnd* pParentWnd, x::UINT nID);
 	void	SetStyle();
 	void	CreateMenues();
 	void	Localize();
@@ -84,11 +84,11 @@ public:
 protected:
 	void OnColResize(wxListEvent& evt);
 
-	void DrawFileItem(wxDC* dc,int nColumn,LPRECT lpRect, CtrlItem_Struct* lpCtrlItem);
-	void DrawSourceItem(wxDC* dc,int nColumn,LPRECT lpRect, CtrlItem_Struct* lpCtrlItem);
+	void DrawFileItem(wxDC* dc,int nColumn,x::LPRECT lpRect, CtrlItem_Struct* lpCtrlItem);
+	void DrawSourceItem(wxDC* dc,int nColumn,x::LPRECT lpRect, CtrlItem_Struct* lpCtrlItem);
 	/*
-	void	DrawFileItem(CDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
-	void	DrawSourceItem(CDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
+	void	DrawFileItem(CDC *dc, int nColumn, x::LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
+	void	DrawSourceItem(CDC *dc, int nColumn, x::LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
 	afx_msg void OnLvnItemActivate(NMHDR *pNMHDR, LRESULT *pResult);
 	afx_msg void OnNMReleasedcapture(NMHDR *pNMHDR, LRESULT *pResult);
 	afx_msg void OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult);
