@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -80,7 +80,7 @@ void CFriendListCtrl::Init()
     //theApp.friendlist->ShowFriends();
 #if 0
     SetExtendedStyle(LVS_EX_FULLROWSELECT);
-    RECT rcWindow;
+    x::RECT rcWindow;
     GetWindowRect( &rcWindow);
     InsertColumn(0, GetResString(IDS_QL_USERNAME), LVCFMT_LEFT,
     rcWindow.right - rcWindow.left - 4, 0);
@@ -181,7 +181,7 @@ void CFriendListCtrl::OnNMRclick(wxMouseEvent &evt)
 #if 0
 void CFriendListCtrl::OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult)
 {
-    POINT point;
+    x::POINT point;
     ::GetCursorPos( &point);
     CFriend *cur_friend;
     if (m_ClientMenu) m_ClientMenu.DestroyMenu();
