@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Tiku ( )
@@ -9,12 +9,12 @@
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,22 +22,23 @@
 // ClientDetailDialog.cpp : implementation file
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "HTTPDownloadDlg.h"
+#	include "otherfunctions.h"
+#	include "animate.h"
+#	include "muuli_wdr.h"
 #endif
 
-#include "HTTPDownloadDlg.h"                // Needed for this Interface's Prototype
+#include "inetdownload.h"
 
-#include "animate.h"                        // Needed for wxGIFAnimationCtrl
-#include "inetdownload.h"                   // Needed for inetDownload
-#include "muuli_wdr.h"                      // Needed for downloadDlg
-
-#include <wx/dialog.h>                      // Needed for wxDialog
-#include <wx/intl.h>                        // Needed for _
-#include <wx/msgdlg.h>                      // Needed for wxMessageBox
-#include <wx/sizer.h>                       // Needed for wxSizer::Show
+#include <wx/msgdlg.h>                      // Needed for wxMessageDialog
+#include <wx/sizer.h>                       // Needed for wxSizer
 
 BEGIN_EVENT_TABLE(CHTTPDownloadDlg, wxDialog)
-EVT_BUTTON(ID_CANCEL, CHTTPDownloadDlg::OnBtnCancel)
+    EVT_BUTTON(ID_CANCEL, CHTTPDownloadDlg::OnBtnCancel)
 END_EVENT_TABLE()
 
 CHTTPDownloadDlg::CHTTPDownloadDlg(wxWindow *parent, wxString url, wxString tempName)
