@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // parts of this file are based on work from pan One (http://home-3.tiscali.nl/~meost/pms/)
@@ -148,11 +148,11 @@ void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bo
 
  
  /*
- DWORD crBoth;
- DWORD crNeither;
- DWORD crClientOnly;
- DWORD crPending;
- DWORD crNextPending;
+ x::DWORD crBoth;
+ x::DWORD crNeither;
+ x::DWORD crClientOnly;
+ x::DWORD crPending;
+ x::DWORD crNextPending;
  if(bFlat) {
  crBoth = RGB(0, 150, 0);
  crNeither = RGB(224, 224, 224);
@@ -176,7 +176,7 @@ void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bo
         for (int i = 0 ; i != GetPartCount() ; i++)
         if (m_AvailPartFrequency[i] > 0)
         {
-            DWORD color = RGB(0, (210 - (22 * (m_AvailPartFrequency[i]
+            x::DWORD color = RGB(0, (210 - (22 * (m_AvailPartFrequency[i]
             - 1)) < 0) ? 0: 210 - (22 * (m_AvailPartFrequency[i] - 1)), 255);
             s_ShareStatusBar.FillRange(PARTSIZE * (i), PARTSIZE
             * (i + 1), color);
@@ -242,7 +242,8 @@ void CKnownFile::SetPath(const wxString& path)
         delete[] directory;
     }
 
-    directory = new char[path.length()];
+    // Bug found + fixed by Uri on 18 May 2005
+    directory = new char[path.length() + 1];
     strcpy(directory, path.c_str());
 }
 
