@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -409,7 +409,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32_t size, uint8_t opcode
     case OP_QUEUERANK:
         {
             theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
-            CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+            CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
             uint32_t rank;
             data->Read( &rank, 4);
             client->SetRemoteQueueRank(rank);
@@ -429,7 +429,7 @@ bool CClientReqSocket::ProcessPacket(char *packet, uint32_t size, uint8_t opcode
     case OP_REQUESTPARTS:
         {
             theApp.downloadqueue->AddDownDataOverheadFileRequest(size);
-            CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+            CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
             unsigned char reqfilehash[16];
             data->Read(reqfilehash, 16);
             Requested_Block_Struct *reqblock1 = new Requested_Block_Struct;
@@ -865,7 +865,7 @@ if(client) {
                     file = theApp.downloadqueue->GetFileByID((unsigned char *) packet);
                     if (file)
                     {
-                        DWORD dwTimePassed =::GetTickCount() - client->GetLastSrcReqTime() + CONNECTION_LATENCY;
+                        x::DWORD dwTimePassed =::GetTickCount() - client->GetLastSrcReqTime() + CONNECTION_LATENCY;
                         bool bNeverAskedBefore = client->GetLastSrcReqTime() == 0;
                         if (
                         //if not complete and file is rare, allow once every 10 minutes
@@ -892,7 +892,7 @@ if(client) {
     case OP_ANSWERSOURCES:
         {
             theApp.downloadqueue->AddDownDataOverheadSourceExchange(size);
-            CSafeMemFile data((BYTE *) packet, size);
+            CSafeMemFile data((x::BYTE *) packet, size);
             unsigned char hash[16];
             data.Read(hash, 16);
             CKnownFile *file = theApp.downloadqueue->GetFileByID((unsigned char *) packet);
