@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -74,7 +74,7 @@ CMuleListCtrl::~CMuleListCtrl()
     delete[] m_aColumns;
 }
 
-void CMuleListCtrl::SetNamxMule(LPCTSTR lpszName)
+void CMuleListCtrl::SetNamxMule(x::LPCTSTR lpszName)
 {
     m_Name = lpszName;
 }
@@ -99,7 +99,7 @@ void CMuleListCtrl::ShowColumn(int iColumn)
 void CMuleListCtrl::SaveSettings(const short int tID)
 {
     int colTrack = GetColumnCount();
-    INT *piArray = new INT[colTrack];
+    x::INT *piArray = new x::INT[colTrack];
     for (int i = 0 ; i < colTrack ; i++)
     {
         wxListItem mycol;
@@ -117,7 +117,7 @@ void CMuleListCtrl::LoadSettings(const short int tID)
 {
     //CHeaderCtrl* pHeaderCtrl = GetHeaderCtrl();
     int colTrack = GetColumnCount();
-    INT *piArray = new INT[colTrack];
+    x::INT *piArray = new x::INT[colTrack];
     for (int i = 0 ; i < colTrack ; i++)
     {
         int iWidth = theApp.glob_prefs->GetColumnWidth(tID, i);
