@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@ public:
 	virtual ~CMuleListCtrl();
 
 	// Sets the list name, used for hide/show menu
-	void SetNamxMule(LPCTSTR lpszName);
+	void SetNamxMule(x::LPCTSTR lpszName);
 
 	// Forces the control to repaint a specific item.
 	bool Update(int nItem);
@@ -87,12 +87,12 @@ protected:
 	wxString          m_Name;
 	wxMenu *m_ColumnMenu;
 	bool             m_bCustomDraw;
-	COLORREF         m_crWindow;
-	COLORREF         m_crWindowText;
-	COLORREF         m_crHighlight;
-	COLORREF         m_crFocusLine;
-	COLORREF         m_crNoHighlight;
-	COLORREF         m_crNoFocusLine;
+	x::COLORREF         m_crWindow;
+	x::COLORREF         m_crWindowText;
+	x::COLORREF         m_crHighlight;
+	x::COLORREF         m_crFocusLine;
+	x::COLORREF         m_crNoHighlight;
+	x::COLORREF         m_crNoFocusLine;
 	void OnColumnRclick(wxListEvent& evt);
 private:
 	//static int IndexToOrder(CHeaderCtrl* pHeader, int iIndex);
