@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -55,7 +55,7 @@ COScopeCtrl::COScopeCtrl(int NTrends, wxWindow *parent)
 : wxControl(parent, - 1, wxDefaultPosition, wxDefaultSize), m_nRedrawTimer(this, TIMER_OSCOPE)
 {
     int i;
-    COLORREF PresetColor [ 16 ] =
+    x::COLORREF PresetColor [ 16 ] =
     {
         RGB(0xFF, 0x00, 0x00),
         RGB(0xFF, 0xC0, 0xC0),
@@ -192,8 +192,8 @@ END_MESSAGE_MAP()
 
 /////////////////////////////////////////////////////////////////////////////
 #if 0
-bool COScopeCtrl::Create(DWORD dwStyle, const RECT &rect,
-CWnd *pParentWnd, UINT nID)
+bool COScopeCtrl::Create(x::DWORD dwStyle, const x::RECT &rect,
+CWnd *pParentWnd, x::UINT nID)
 {
     bool result;
     static wxString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
@@ -264,7 +264,7 @@ void COScopeCtrl::SetYUnits(wxString string, wxString YMin, wxString YMax)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl::SetGridColor(COLORREF color)
+void COScopeCtrl::SetGridColor(x::COLORREF color)
 {
     m_crGridColor = color;
     // clear out the existing garbage, re-start with a clean plot
@@ -273,7 +273,7 @@ void COScopeCtrl::SetGridColor(COLORREF color)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl::SetPlotColor(COLORREF color, int iTrend)
+void COScopeCtrl::SetPlotColor(x::COLORREF color, int iTrend)
 {
     m_PlotData[ iTrend ].crPlotColor = color;
     //m_PlotData[ iTrend ].penPlot.DeleteObject() ;
@@ -284,14 +284,14 @@ void COScopeCtrl::SetPlotColor(COLORREF color, int iTrend)
     // SetPlotColor:
 }
 
-COLORREF COScopeCtrl::GetPlotColor(int iTrend)
+x::COLORREF COScopeCtrl::GetPlotColor(int iTrend)
 {
     return m_PlotData[ iTrend ].crPlotColor;
     // GetPlotColor:
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl::SetBackgroundColor(COLORREF color)
+void COScopeCtrl::SetBackgroundColor(x::COLORREF color)
 {
     m_crBackColor = color;
     //m_brushBack.DeleteObject() ;
@@ -485,7 +485,7 @@ m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
  if( m_str.XMin.IsEmpty() )
  m_dcGrid.TextOut (m_rectPlot.left, m_rectPlot.bottom+4, "0") ;
  else
- m_dcGrid.TextOut( m_rectPlot.left, m_rectPlot.bottom+4, (LPCTSTR)m_str.XMin );
+ m_dcGrid.TextOut( m_rectPlot.left, m_rectPlot.bottom+4, (x::LPCTSTR)m_str.XMin );
  // x max
  m_dcGrid.SetTextAlign (TA_RIGHT|TA_TOP) ;
  if( m_str.XMax.IsEmpty() ){
@@ -644,7 +644,7 @@ void COScopeCtrl::AppendPoints(double dNewPoint[], bool bInvalidate, bool bAdd2L
 void COScopeCtrl::AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool bAdd2List)
 {
     int iTrend, currY;
-    RECT ScrollRect, rectCleanUp;
+    x::RECT ScrollRect, rectCleanUp;
     // append a data point to the plot
     // return the previous point
     for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
@@ -763,7 +763,7 @@ void COScopeCtrl::DrawPoint()
     // the will subsequently be BitBlt'd to the client in OnPaint
     int currX, prevX, currY, prevY, iTrend;
     //CPen *oldPen ;
-    RECT ScrollRect, rectCleanUp;
+    x::RECT ScrollRect, rectCleanUp;
     if (m_dcPlot != NULL)
     {
         //	BitBlt was replaced by call to ScrollDC
@@ -994,7 +994,7 @@ int COScopeCtrl::ReCreateGraph(void)
     return 0;
 }
 
-//void COScopeCtrl::OnTimer(UINT nIDEvent)
+//void COScopeCtrl::OnTimer(x::UINT nIDEvent)
 void COScopeCtrl::OnTimer(wxTimerEvent &evt)
 {
     if (!theApp.xmuledlg->IsRunning())
