@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -51,10 +51,10 @@ public:
 	void SetRanges(double dLower, double dUpper);
 	void SetXUnits(wxString string, wxString XMin = "", wxString XMax = "");
 	void SetYUnits(wxString string, wxString YMin = "", wxString YMax = "");
-	void SetGridColor(COLORREF color);
-	void SetPlotColor(COLORREF color, int iTrend = 0);
-	COLORREF GetPlotColor(int iTrend = 0);
-	void SetBackgroundColor(COLORREF color);
+	void SetGridColor(x::COLORREF color);
+	void SetPlotColor(x::COLORREF color, int iTrend = 0);
+	x::COLORREF GetPlotColor(int iTrend = 0);
+	void SetBackgroundColor(x::COLORREF color);
 	void InvalidateCtrl(bool deleteGraph = true);
 	void DrawPoint();
 	void Reset();
@@ -66,7 +66,7 @@ public:
 	// ClassWizard generated virtual function overrides
 	//{{AFX_VIRTUAL(COScopeCtrl)
 	public:
-	//virtual bool Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID=NULL);
+	//virtual bool Create(x::DWORD dwStyle, const x::RECT& rect, CWnd* pParentWnd, x::UINT nID=NULL);
 	//}}AFX_VIRTUAL
 
  private:
@@ -94,11 +94,11 @@ public:
 	} m_str_t;
 	m_str_t m_str;
 
-	COLORREF m_crBackColor;        // background color
-	COLORREF m_crGridColor;        // grid color
+	x::COLORREF m_crBackColor;        // background color
+	x::COLORREF m_crGridColor;        // grid color
 
 	typedef struct PlotDataStruct {
-		COLORREF crPlotColor;       // data plot color  
+		x::COLORREF crPlotColor;       // data plot color  
 		wxPen   penPlot;
 		double dCurrentPosition;    // current position
 		double dPreviousPosition;   // previous position
@@ -120,7 +120,7 @@ protected:
 #if 0
 	//{{AFX_MSG(COScopeCtrl)
 	afx_msg void OnPaint();
-	afx_msg void OnSize(UINT nType, int cx, int cy); 
+	afx_msg void OnSize(x::UINT nType, int cx, int cy); 
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 #endif
@@ -142,8 +142,8 @@ protected:
 	int m_nPlotHeight;
 	int m_nPlotWidth;
 
-	RECT  m_rectClient;
-	RECT  m_rectPlot;
+	x::RECT  m_rectClient;
+	x::RECT  m_rectPlot;
 	wxBrush m_brushBack;
 
 	wxMemoryDC*     m_dcGrid;
@@ -158,10 +158,10 @@ protected:
 	wxTimer m_nRedrawTimer;
 public:
 	int ReCreateGraph(void);
-	//afx_msg void OnTimer(UINT nIDEvent);
+	//afx_msg void OnTimer(x::UINT nIDEvent);
 	void OnTimer(wxTimerEvent& evt);
 
-	void GetPlotRect(RECT& rPlotRect)
+	void GetPlotRect(x::RECT& rPlotRect)
 	{
 		rPlotRect = m_rectPlot;
 	}
