@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -1141,10 +1141,10 @@ typedef unsigned long COLORREF;
 
 void CPartFile::DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool bFlat)
 {
-    COLORREF crProgress;
-    COLORREF crHave;
-    COLORREF crPending;
-    COLORREF crMissing = RGB(255, 0, 0);
+    x::COLORREF crProgress;
+    x::COLORREF crHave;
+    x::COLORREF crPending;
+    x::COLORREF crMissing = RGB(255, 0, 0);
 
     if (bFlat)
     {
@@ -1199,7 +1199,7 @@ void CPartFile::DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool bFlat)
                 }
 
                 // paint
-                COLORREF color;
+                x::COLORREF color;
                 // frequency?:
                 if (m_SrcpartFrequency.GetCount() >= (int) i && m_SrcpartFrequency[i])
                 {
@@ -1236,7 +1236,7 @@ void CPartFile::DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool bFlat)
     s_ChunkBar.Draw(dc, rect.x, rect.y, bFlat);
     // green progress
     float blockpixel = (float)(rect.width - rect.x) / ((float) m_nFileSize);
-    RECT gaprect;
+    x::RECT gaprect;
     gaprect.top = rect.y;
     gaprect.bottom = gaprect.top + 4;
     //->left;:
@@ -1925,7 +1925,7 @@ void CPartFile::CompleteFile(bool bIsHashingDone)
     UpdateDisplayedInfo(this, m_lastRefreshedDLDisplay, true);
 }
 
-UINT CPartFile::CompleteThreadProc(CPartFile* pFile)
+x::UINT CPartFile::CompleteThreadProc(CPartFile* pFile)
 {
     if (!pFile)
     {
@@ -2723,7 +2723,7 @@ int CPartFile::GetCommonFilePenalty()
  fill a gap.
    */
 
-uint32_t CPartFile::WriteToBuffer(uint32_t transize, BYTE* data, uint32_t start, uint32_t end, Requested_Block_Struct* block)
+uint32_t CPartFile::WriteToBuffer(uint32_t transize, x::BYTE* data, uint32_t start, uint32_t end, Requested_Block_Struct* block)
 {
     // Increment transfered bytes counter for this file
     transfered += transize;
@@ -2742,7 +2742,7 @@ uint32_t CPartFile::WriteToBuffer(uint32_t transize, BYTE* data, uint32_t start,
     }
 
     // Create copy of data as new buffer
-    BYTE* buffer = new BYTE[lenData];
+    x::BYTE* buffer = new x::BYTE[lenData];
     memcpy(buffer, data, lenData);
     // Create a new buffered queue entry
     PartFileBufferedData* item = new PartFileBufferedData;
