@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -28,7 +28,7 @@
 #include "mfc.h"                            // CList CTypedPtrList - audited 4 Nov 2004
 #include "NewFunctions.h"                   // MAP - audited 5 Nov 2004
 #include "otherfunctions.h"                 // GetTickCount - audited 5 Nov 2004
-#include "wintypes.h"                       // bool BYTE - audited 4 Nov 2004
+#include "wintypes.h"                       // bool x::BYTE - audited 4 Nov 2004
 
 #include <stdint.h>                         // uint32_t
 #include <wx/dc.h>
@@ -66,7 +66,7 @@ class Requested_Block_Struct;
 
 struct PartFileBufferedData
 {
-    BYTE *data;                     // Barry - This is the data to be written
+    x::BYTE *data;                     // Barry - This is the data to be written
     uint32_t start;                 // Barry - This is the start offset of the data
     uint32_t end;                   // Barry - This is the end offset of the data
     Requested_Block_Struct *block;  // Barry - This is the requested block that this data relates to
@@ -123,7 +123,7 @@ public:
         wxString GetDownloadFileInfo();
 
     // Barry - Added as replacement for BlockReceived to buffer data before writing to disk
-    uint32_t    WriteToBuffer(uint32_t transize, BYTE *data, uint32_t start, uint32_t end, Requested_Block_Struct *block);
+    uint32_t    WriteToBuffer(uint32_t transize, x::BYTE *data, uint32_t start, uint32_t end, Requested_Block_Struct *block);
     void    FlushBuffer(void);
 
     // Barry - Is archive recovery in progress
@@ -190,7 +190,7 @@ private:
     bool    HashSinglePart(uint16_t partnumber); // true = ok , false = corrupted   
     void    RemoveAllSources(bool bTryToSwap);
     bool    PerformFileComplete(); // Lord KiRon
-    static UINT CompleteThreadProc(CPartFile* pFile); // Lord KiRon - Used as separate thread to complete file
+    static x::UINT CompleteThreadProc(CPartFile* pFile); // Lord KiRon - Used as separate thread to complete file
     void    CompleteFile(bool hashingdone);
     void    UpdateCompletedInfos();
     void    AddGap(uint32_t start, uint32_t end);
