@@ -2,7 +2,7 @@
 //
 // Clean Up, Fix some things and partly rewrite this File: Plaenky 
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -131,8 +131,8 @@ void CPreferences::SetStandartValues()
     wxString buffer;
     CreateUserHash();
     md4cpy( &prefs->userhash, &userhash);
-    WINDOWPLACEMENT defaultWPM;
-    defaultWPM.length = sizeof(WINDOWPLACEMENT);
+    x::WINDOWPLACEMENT defaultWPM;
+    defaultWPM.length = sizeof(x::WINDOWPLACEMENT);
     defaultWPM.rcNormalPosition.left = 10;
     defaultWPM.rcNormalPosition.top = 10;
     defaultWPM.rcNormalPosition.right = 700;
@@ -239,7 +239,7 @@ int CPreferences::GetRecommendedMaxConnections()
     return iRealMax - 20;
 }
 
-WORD CPreferences::GetWindowsVersion()
+x::WORD CPreferences::GetWindowsVersion()
 {
     return 1;
 }
@@ -283,7 +283,7 @@ void CPreferences::ResetStatsColor(int index)
     default:break;
     }
 }
-
+#include <iostream>
 void CPreferences::SavePreferences(void)
 {
     wxString buffer;
@@ -479,14 +479,14 @@ bool CPreferences::LoadPreferences(void)
     error = wxFileExists(full_path) == false;
     // Use CIni anyway to load or to create the values
     CIni ini(full_path, "eMule");
-
+    theApp.dynprefs->Add("accept-license",         ini.GetBool("AcceptLicense", true));
     theApp.dynprefs->Add("nickname",               ini.GetString("Nick", "http://www.xmule.ws/"));
     theApp.dynprefs->Add("incoming-directory",     ini.GetString("IncomingDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Incoming").c_str())));
     theApp.dynprefs->Add("temp-directory",         ini.GetString("TempDir", const_cast<char *>(wxString(theApp.dynprefs->Get<wxString>("app-directory") + "Temp").c_str())));
     theApp.dynprefs->Add("limits-upload",          static_cast<long>(ini.GetInt("MaxUpload", UNLIMITED)));
     theApp.dynprefs->Add("limits-download",        static_cast<long>(ini.GetInt("MaxDownload", UNLIMITED)));
     theApp.dynprefs->Add("max-connections",        static_cast<long>(ini.GetInt("MaxConnections", 500)));
-    theApp.dynprefs->Add("remove-dead-server",     static_cast<long>(ini.GetInt("RemoveDeadServer", 2)));
+    theApp.dynprefs->Add("remove-dead-server",     static_cast<bool>(ini.GetInt("RemoveDeadServer", 2)));
     theApp.dynprefs->Add("tcp-port",               static_cast<long>(ini.GetInt("Port", 4662)));
     theApp.dynprefs->Add("udp-port",               static_cast<long>(ini.GetInt("UDPPort", theApp.dynprefs->Get<long>("tcp-port") + 10)));
     theApp.dynprefs->Add("max-sources",            static_cast<long>(ini.GetInt("MaxSourcesPerFile", 400)));
@@ -1106,7 +1106,7 @@ int CPreferences::GetColumnOrder(const short int t, int index) const
     return 0;
 }
 
-void CPreferences::SetColumnOrder(const short int t, INT *piOrder)
+void CPreferences::SetColumnOrder(const short int t, x::INT *piOrder)
 {
     switch (t)
     {
