@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -60,7 +60,7 @@ wxThread::ExitCode CPreviewThread::Entry()
         if (bFullSized)
         destFile.SetLength(nSize);
         destFile.SeekToBegin();
-        BYTE abyBuffer[4096];
+        x::BYTE abyBuffer[4096];
         uint32_t nRead;
         while (destFile.GetPosition() + 4096 < PARTSIZE *2)
         {
