@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -345,8 +345,8 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
     //dc.SelectObject(GetFont());
     //COLORREF crOldTextColor = dc->GetTextColor();
     //COLORREF crOldBkColor = dc->GetBkColor();
-    RECT cur_rec;
-    //memcpy(&cur_rec,&lpDrawItemStruct->rcItem,sizeof(RECT));
+    x::RECT cur_rec;
+    //memcpy(&cur_rec,&lpDrawItemStruct->rcItem,sizeof(x::RECT));
     cur_rec.left = rect.x;
     cur_rec.top = rect.y;
     cur_rec.right = rect.x + rect.width;
@@ -414,7 +414,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                     // Added Thief Icon [BlackRat]
                     if (client->thief)
                     image = 9;
-                    POINT point =
+                    x::POINT point =
                     {
                         cur_rec.left, cur_rec.top + 1
                                         };
@@ -520,7 +520,7 @@ END_MESSAGE_MAP()
 // CQueueListCtrl message handlers
 void CQueueListCtrl::OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult)
 {
-    POINT point;
+    x::POINT point;
     ::GetCursorPos( &point);
     m_ClientMenu.TrackPopupMenu(TPM_LEFTALIGN |TPM_RIGHTBUTTON, point.x, point.y, this);
     *pResult = 0;
@@ -691,7 +691,7 @@ void CQueueListCtrl::OnTimer(wxTimerEvent &evt)
 }
 
 // Barry - Refresh the queue every 10 secs
-//HWND hwnd, UINT uiMsg, UINT idEvent, DWORD dwTime):
+//HWND hwnd, x::UINT uiMsg, x::UINT idEvent, x::DWORD dwTime):
 void CQueueListCtrl::QueueUpdateTimer()
 {
     // Don't do anything if the app is shutting down - can cause unhandled exceptions
