@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -26,7 +26,7 @@
 #	include "SafeFile.h"
 #endif
 
-CSafeFile::CSafeFile(LPCSTR lpszFileName, UINT nOpenFlags)
+CSafeFile::CSafeFile(x::LPCSTR lpszFileName, x::UINT nOpenFlags)
 : CFile(lpszFileName, (CFile::OpenMode) nOpenFlags)
 //:CFile(lpszFileName,nOpenFlags)
 {
@@ -37,27 +37,27 @@ CSafeFile::CSafeFile(): CFile()
 {
 }
 
-UINT CSafeFile::Read(void *lpBuf, UINT nCount)
+x::UINT CSafeFile::Read(void *lpBuf, x::UINT nCount)
 {
     if (Tell() + nCount > Length())
     {
         //		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
-        return(UINT) - 1;
+        return(x::UINT) - 1;
     }
     return CFile::Read(lpBuf, nCount);
 }
 
-CSafeMemFile::CSafeMemFile(BYTE *lpBuffer, UINT nBufferSize, UINT nGrowBytes)
+CSafeMemFile::CSafeMemFile(x::BYTE *lpBuffer, x::UINT nBufferSize, x::UINT nGrowBytes)
 : CMemFile(lpBuffer, nBufferSize, nGrowBytes)
 {
     // Nothing to do here
 }
 
-CSafeMemFile::CSafeMemFile(UINT nGrowBytes): CMemFile(nGrowBytes)
+CSafeMemFile::CSafeMemFile(x::UINT nGrowBytes): CMemFile(nGrowBytes)
 {
 }
 
-UINT CSafeMemFile::Read(void *lpBuf, UINT nCount)
+x::UINT CSafeMemFile::Read(void *lpBuf, x::UINT nCount)
 {
     if (GetPosition() + nCount > this->GetLength())
     {
