@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This file was a part of eMule
@@ -197,18 +197,16 @@ wxString type[7] =
 {
     SDRES(IDS_SEARCH_ANY),
     SDRES(IDS_SEARCH_ARC),
-    SDRES(IDS_SEARCH_AUDIO),
     SDRES(IDS_SEARCH_PICS),
     SDRES(IDS_SEARCH_CDIMG),
     SDRES(IDS_SEARCH_PRG),
-    SDRES(IDS_SEARCH_VIDEO)
 }
 
 ;
 
 wxString method[5] =
 {
-    "Server", "Global (Server)", "Jigle", "Jigle (Web)", "FileDonkey (Web)"
+    "Server", "Global (Server)"
 }
 
 ;
