@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -160,7 +160,7 @@ CSearchFile::CSearchFile(char *in_data, wxUint32 nSearchID)
     m_bPreviewPossible = false;
 }
 
-CSearchFile::CSearchFile(CFile *in_data, uint32_t nSearchID, uint32_t nServerIP, uint16_t nServerPort, LPCTSTR pszDirectory)
+CSearchFile::CSearchFile(CFile *in_data, uint32_t nSearchID, uint32_t nServerIP, uint16_t nServerPort, x::LPCTSTR pszDirectory)
 {
     m_nSearchID = nSearchID;
     in_data->Read( &m_abyFileHash, 16);
