@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -39,7 +39,7 @@ class CSearchFile : public CAbstractFile {
 public:
 	//CSearchFile() {};
 	CSearchFile(char* data, wxUint32 nSearchID);
-	CSearchFile(CFile* in_data, wxUint32 nSearchID, wxUint32 nServerIP=0, uint16_t nServerPort=0, LPCTSTR pszDirectory = NULL);
+	CSearchFile(CFile* in_data, wxUint32 nSearchID, wxUint32 nServerIP=0, uint16_t nServerPort=0, x::LPCTSTR pszDirectory = NULL);
 	CSearchFile(wxUint32 nSearchID, const unsigned char* pucFileHash, wxUint32 uFileSize, char *pszFileName, int iFileType, int iAvailability);
 
 	~CSearchFile();
