@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 //Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -715,7 +715,7 @@ void CServerList::CancelUDPBroadcast()
 }
 
 #if 0
-void CALLBACK CServerList::UDPTimerProc(HWND hwnd, UINT uMsg, UINT_PTR idEvent, DWORD dwTime)
+void CALLBACK CServerList::UDPTimerProc(HWND hwnd, x::UINT uMsg, x::UINT_PTR idEvent, x::DWORD dwTime)
 {
     theApp.serverlist->SendNextPacket();
 }
