@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 //Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -23,24 +23,25 @@
 
 #ifdef PRECOMP
 #	include "xmule-headers.h"
-#else
-#	include "ServerListCtrl.h"
-#	include "DownloadQueue.h"
-#	include "muuli_wdr.h"
+#endif
+
+#include "ServerListCtrl.h"
+#include "DownloadQueue.h"
+#include "muuli_wdr.h"
 #include "opcodes.h"                        // MP_PRIOLOW
-#	include "otherfunctions.h"
+#include "otherfunctions.h"
 #include "PartFile.h"                       // Needed for SRV_PR_HIGH - audited 5 Nov 2004
 #include "Preferences.h"                    // CPreferences::List Settings
 #include "server.h"                         // Needed for CServer - audited 5 Nov 2004
 #include "ServerList.h"                     // CServerList
-#	include "ServerWnd.h"
-#	include "sockets.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#endif
+#include "ServerWnd.h"
+#include "sockets.h"
+#include "xmule.h"
+#include "xmuleDlg.h"
 
 #include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
+#include <wx/menu.h>                        // wxMenu
 #include <wx/stattext.h>                    // wxStaticText
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
@@ -499,7 +500,7 @@ END_MESSAGE_MAP()
 
 void CServerListCtrl::OnNMRclickServlist(NMHDR *pNMHDR, LRESULT *pResult)
 {
-    POINT point;
+    x::POINT point;
     ::GetCursorPos( &point);
     // tecxx 0609 2002
     // fix - on right click, we also want to change the current selection like the left click does
@@ -511,7 +512,7 @@ void CServerListCtrl::OnNMRclickServlist(NMHDR *pNMHDR, LRESULT *pResult)
     SetSelectionMark(it);
     // fix end
     // Create up-to-date popupmenu
-    UINT flags;
+    x::UINT flags;
     CTitleMenu m_ServerMenu;
     CMenu m_ServerPrioMenu;
     // set state of selection-dependent menuitems
@@ -525,7 +526,7 @@ void CServerListCtrl::OnNMRclickServlist(NMHDR *pNMHDR, LRESULT *pResult)
     m_ServerMenu.CreatePopupMenu();
     m_ServerMenu.AddMenuTitle(GetResString(IDS_EM_SERVER));
     m_ServerMenu.AppendMenu(flags, MP_CONNECTTO, GetResString(IDS_CONNECTTHIS));
-    m_ServerMenu.AppendMenu(flags |MF_POPUP, (UINT_PTR) m_ServerPrioMenu.m_hMenu, GetResString(IDS_PRIORITY));
+    m_ServerMenu.AppendMenu(flags |MF_POPUP, (x::UINT_PTR) m_ServerPrioMenu.m_hMenu, GetResString(IDS_PRIORITY));
     m_ServerMenu.AppendMenu(flags, MP_ADDTOSTATIC, GetResString(IDS_ADDTOSTATIC));
     m_ServerMenu.AppendMenu(MF_STRING |MF_SEPARATOR);
     m_ServerMenu.AppendMenu(flags, MP_REMOVE, GetResString(IDS_REMOVETHIS));
