@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -44,6 +44,7 @@
 
 #include <DynPrefs/DynPrefs.h>              // Needed for DynamicPreferences
 
+#include <netinet/in.h>                     // Needed before arpa/inet.h for BSD systems
 #include <arpa/inet.h>                      // Needed for sockaddr_in
 
 class ServerSocketEvt: public wxEvtHandler
@@ -151,14 +152,24 @@ void CServerSocket::OnConnect(int nErrorCode)
             // hmm?? argument list too big
             m_bIsDeleting = true;
             SetConnectionState(CS_SERVERDEAD);
-            serverconnect->DestroySocket(this);
+
+            if (serverconnect)
+            {
+                serverconnect->DestroySocket(this);
+            }
+
             break;
         }
     default:
         {
             m_bIsDeleting = true;
             SetConnectionState(CS_FATALERROR);
-            serverconnect->DestroySocket(this);
+
+
+            if (serverconnect)
+            {
+                serverconnect->DestroySocket(this);
+            }
             break;
         }
     }
@@ -170,7 +181,7 @@ void CServerSocket::OnInput(int nErrorCode)
 #if defined(__DEBUG__)
     //printf("CServerSocket::OnInput errno=%ld nErrorCode=%ld\n", errno, nErrorCode);
 #endif
-    if (connectionstate != CS_CONNECTED && !this->serverconnect->IsConnecting())
+    if (connectionstate != CS_CONNECTED && this->serverconnect && !this->serverconnect->IsConnecting())
     {
         serverconnect->DestroySocket(this);
     }
@@ -271,7 +282,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32_t size, int8_t opcode)
                     }
                 }
                 // Added by sivka [Tarod/sivka -auto reconnect on LowID]
-                if ((la->clientid < 16777216) &&
+                if ((la->clientid < 16777216) && serverconnect &&
                 //theApp.glob_prefs->ReconnectLowID() &&
                 (serverconnect->GetLowIDTries() < 3))
                 {
@@ -317,7 +328,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32_t size, int8_t opcode)
 #if defined(__DEBUG__)
             //printf("CServerSocket::ProcessPacket OP_FOUNDSOURCES %02x size=%ld\n", opcode, size);
 #endif
-            CMemFile *sources = new CMemFile((BYTE *) packet, size);
+            CMemFile *sources = new CMemFile((x::BYTE *) packet, size);
             unsigned char fileid[16];
             sources->Read(fileid, 16);
             if (CPartFile *file = theApp.downloadqueue->GetFileByID(fileid))
@@ -393,7 +404,7 @@ bool CServerSocket::ProcessPacket(char *packet, int32_t size, int8_t opcode)
 #if defined(__DEBUG__)
                 //printf("CServerSocket::ProcessPacket OP_SERVERLIST %02x size=%ld\n", opcode, size);
 #endif
-                CSafeMemFile *servers = new CSafeMemFile((BYTE *) packet, size);
+                CSafeMemFile *servers = new CSafeMemFile((x::BYTE *) packet, size);
                 unsigned char count;
                 // (servercount*(4bytes ip + 2bytes port) + 1byte servercount):
                 if ((1 != servers->Read( &count, 1)) || ((int32_t)(count *6 + 1) > size))
@@ -469,6 +480,9 @@ void CServerSocket::ConnectToServer(CServer *server)
     wxIPV4address addr;
     addr.Hostname(server->GetAddress());
     addr.Service(server->GetPort());
+
+    SetConnectionState(CS_CONNECTING);
+
     if (!this->Connect(addr, FALSE))
     {
         //this->GetLastError();:
@@ -481,7 +495,6 @@ void CServerSocket::ConnectToServer(CServer *server)
         }
     }
     info = server->GetListName();
-    SetConnectionState(CS_CONNECTING);
 }
 
 void CServerSocket::OnLost(int nErrorCode)
@@ -530,7 +543,11 @@ void CServerSocket::OnClose(int nErrorCode)
     {
         SetConnectionState(CS_NOTCONNECTED);
     }
-    serverconnect->DestroySocket(this);
+
+    if (serverconnect)
+    {
+        serverconnect->DestroySocket(this);
+    }
 }
 
 void CServerSocket::SetConnectionState(int8_t newstate)
