@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -121,8 +121,8 @@ void CSharedFilesCtrl::Init()
     m_PermMenu.AppendMenu(MF_STRING, MP_PERMFRIENDS, GetResString(IDS_FSTATUS_FRIENDSONLY));
     m_PermMenu.AppendMenu(MF_STRING, MP_PERMALL, GetResString(IDS_FSTATUS_PUBLIC));
     // todo enable when it works
-    m_SharedFilesMenu.AppendMenu(MF_STRING |MF_POPUP, (UINT_PTR) m_PrioMenu.m_hMenu, GetResString(IDS_PRIORITY));
-    //m_SharedFilesMenu.AppendMenu(MF_STRING|MF_POPUP,(UINT_PTR)m_PermMenu.m_hMenu, (LPCTSTR)"Permissions");
+    m_SharedFilesMenu.AppendMenu(MF_STRING |MF_POPUP, (x::UINT_PTR) m_PrioMenu.m_hMenu, GetResString(IDS_PRIORITY));
+    //m_SharedFilesMenu.AppendMenu(MF_STRING|MF_POPUP,(x::UINT_PTR)m_PermMenu.m_hMenu, (x::LPCTSTR)"Permissions");
     m_SharedFilesMenu.AppendMenu(MF_STRING |MF_SEPARATOR);
     m_SharedFilesMenu.AppendMenu(MF_STRING, MP_OPEN, GetResString(IDS_OPENFILE));
     m_SharedFilesMenu.AppendMenu(MF_STRING, MP_GETED2KLINK, GetResString(IDS_DL_LINK1));
@@ -401,7 +401,7 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent &evt)
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
     wxCommandEvent &event = (wxCommandEvent &) evt;
-    UINT selectedCount = this->GetSelectedItemCount();
+    x::UINT selectedCount = this->GetSelectedItemCount();
     //GetSelectionMark();:
     int iSel = GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
     if (iSel != ( - 1))
