@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -84,15 +84,15 @@ public:
 // Implementation
 public:
 	static void ChangePos(wxWindow* pWnd, int dx, int dy);
-	static void ChangeWidth(wxWindow* pWnd, int dx, DWORD dwFlag = CW_LEFTALIGN);
-	static void ChangeHeight(wxWindow* pWnd, int dy, DWORD dwFlag = CW_TOPALIGN);
+	static void ChangeWidth(wxWindow* pWnd, int dx, x::DWORD dwFlag = CW_LEFTALIGN);
+	static void ChangeHeight(wxWindow* pWnd, int dy, x::DWORD dwFlag = CW_TOPALIGN);
 public:
 	void		SetRange(int nMin, int nMax);
 	void		SetRange(int nSubtraction, int nAddition, int nRoot);
 
 	int			GetStyle();
 	int			SetStyle(int nStyle = SPS_VERTICAL);
-	void		Create(DWORD dwStyle, const wxRect& rect, wxWindow* pParent, UINT nID);
+	void		Create(x::DWORD dwStyle, const wxRect& rect, wxWindow* pParent, x::UINT nID);
 	virtual		~CSplitterControl();
 
 	// Generated message map functions
@@ -102,10 +102,10 @@ protected:
 #if 0
 	//{{AFX_MSG(CSplitterControl)
 	afx_msg void	OnPaint();
-	afx_msg void	OnMouseMove(UINT nFlags, CPoint point);
-	afx_msg bool	OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
-	afx_msg void	OnLButtonDown(UINT nFlags, CPoint point);
-	afx_msg void	OnLButtonUp(UINT nFlags, CPoint point);
+	afx_msg void	OnMouseMove(x::UINT nFlags, CPoint point);
+	afx_msg bool	OnSetCursor(CWnd* pWnd, x::UINT nHitTest, x::UINT message);
+	afx_msg void	OnLButtonDown(x::UINT nFlags, CPoint point);
+	afx_msg void	OnLButtonUp(x::UINT nFlags, CPoint point);
 	//}}AFX_MSG
 
 	DECLARE_MESSAGE_MAP()
