@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -262,24 +262,24 @@ void CStatisticsDlg::SetupLegend(int ResIdx, int ElmtIdx, int legendNr)
         //m_Led1[ ElmtIdx ].Create( WS_VISIBLE | WS_CHILD, Rect, this );
         //m_Led1[ ElmtIdx ].SetBackgroundColor( m_DownloadOMeter.GetPlotColor( ElmtIdx ) );
         //m_Led1[ ElmtIdx ].SetFrameColor( RGB( 0x00, 0x00, 0x00 ) );
-        ctrl->SetBackgroundColor((COLORREF) m_DownloadOMeter->GetPlotColor(ElmtIdx));
-        ctrl->SetFrameColor((COLORREF) RGB(0, 0, 0));
+        ctrl->SetBackgroundColor((x::COLORREF) m_DownloadOMeter->GetPlotColor(ElmtIdx));
+        ctrl->SetFrameColor((x::COLORREF) RGB(0, 0, 0));
     }
     else if(legendNr == 2)
     {
         //m_Led2[ ElmtIdx ].Create( WS_VISIBLE | WS_CHILD, Rect, this );
         //m_Led2[ ElmtIdx ].SetBackgroundColor( m_UploadOMeter.GetPlotColor( ElmtIdx ) );
         //m_Led2[ ElmtIdx ].SetFrameColor( RGB( 0x00, 0x00, 0x00 ) );
-        ctrl->SetBackgroundColor((COLORREF) m_UploadOMeter->GetPlotColor(ElmtIdx));
-        ctrl->SetFrameColor((COLORREF) RGB(0, 0, 0));
+        ctrl->SetBackgroundColor((x::COLORREF) m_UploadOMeter->GetPlotColor(ElmtIdx));
+        ctrl->SetFrameColor((x::COLORREF) RGB(0, 0, 0));
     }
     else if(legendNr == 3)
     {
         //m_Led3[ ElmtIdx ].Create( WS_VISIBLE | WS_CHILD, Rect, this );
         //m_Led3[ ElmtIdx ].SetBackgroundColor( m_Statistics.GetPlotColor( ElmtIdx ) );
         //m_Led3[ ElmtIdx ].SetFrameColor( RGB( 0x00, 0x00, 0x00 ) );
-        ctrl->SetBackgroundColor((COLORREF) m_Statistics->GetPlotColor(ElmtIdx));
-        ctrl->SetFrameColor((COLORREF) RGB(0, 0, 0));
+        ctrl->SetBackgroundColor((x::COLORREF) m_Statistics->GetPlotColor(ElmtIdx));
+        ctrl->SetFrameColor((x::COLORREF) RGB(0, 0, 0));
     }
 }
 
@@ -388,7 +388,7 @@ void CStatisticsDlg::ShowStatistics()
     wxString cbuffer;
     wxString cbuffer2;
     bool resize;
-    DWORD running;
+    x::DWORD running;
     int myStats[11];
     float DownAvgRate;
     resize = false;
@@ -756,7 +756,7 @@ float CStatisticsDlg::GetAvgDownloadRate(int averageType)
     if (averageType == AVG_SESSION)
     {
         if (theApp.stat_transferStarttime == 0) return 0;
-        DWORD running = (GetTickCount() - theApp.stat_transferStarttime) /1000;
+        x::DWORD running = (GetTickCount() - theApp.stat_transferStarttime) /1000;
         if (running < 5) return 0;
         return(float)(theApp.stat_sessionReceivedBytes/1024) / running;
     }
@@ -775,7 +775,7 @@ float CStatisticsDlg::GetAvgUploadRate(int averageType)
     if (averageType == AVG_SESSION)
     {
         if (theApp.stat_transferStarttime == 0) return 0;
-        DWORD running = (GetTickCount() - theApp.stat_transferStarttime) /1000;
+        x::DWORD running = (GetTickCount() - theApp.stat_transferStarttime) /1000;
         if (running < 5) return 0;
         return(float)(theApp.stat_sessionSentBytes/1024) / running;
     }
@@ -789,11 +789,11 @@ float CStatisticsDlg::GetAvgUploadRate(int averageType)
 }
 
 #if 0
-void CStatisticsDlg::OnShowWindow(bool bShow, UINT nStatus)
+void CStatisticsDlg::OnShowWindow(bool bShow, x::UINT nStatus)
 {
 }
 
-void CStatisticsDlg::OnSize(UINT nType, int cx, int cy)
+void CStatisticsDlg::OnSize(x::UINT nType, int cx, int cy)
 {
     CResizableDialog::OnSize(nType, cx, cy);
     // TODO: Add your message handler code here
