@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright(C)2002 Tiku & Patrizio Bassi aka Hetfield <hetfield@email.it>
@@ -69,7 +69,7 @@ gchar *getIP()
 #endif
 
 std::deque<int> m_pLimits;
-std::deque<COLORREF> m_pColors;
+std::deque<x::COLORREF> m_pColors;
 
 #ifndef __SAFE_TRAY__
 gchar *getIP()
@@ -374,7 +374,7 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     if (theApp.Start_time > 0)
     {
-        DWORD running;
+        x::DWORD running;
         running = (GetTickCount() - theApp.Start_time) / 1000;
         tempstring = g_strdup_printf("%s", CastSecondsToHM(running) .GetData());
         info_item = gtk_menu_item_new_with_label(wxString("Uptime: ") + tempstring);
@@ -677,7 +677,7 @@ void CSysTray::setupProperties()
 #endif
 }
 
-void CSysTray::Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DWORD dwTimeToStay, DWORD dwTimeTOHide)
+void CSysTray::Show(const wxChar *caption, int nMsgType, x::DWORD dwTimeToShow, x::DWORD dwTimeToStay, x::DWORD dwTimeTOHide)
 {
 #ifndef __SYSTRAY_DISABLED__
     if (desktopMode == 4)
@@ -708,7 +708,7 @@ void CSysTray::TraySetToolTip(char *data)
 }
 
 // It the nLevel is greater than the values defined in m_pLimits the last value in the array is used
-COLORREF CSysTray::GetMeterColor(int nLevel)
+x::COLORREF CSysTray::GetMeterColor(int nLevel)
 {
 #ifndef __SYSTRAY_DISABLED__
     for (int i = 0 ; i < m_nEntries ; i++)
@@ -804,7 +804,7 @@ void CSysTray::TraySetIcon(char **data, bool what, int *pVals)
 #endif
 }
 
-bool CSysTray::SetColorLevels(int *pLimits, COLORREF *pColors, int nEntries)
+bool CSysTray::SetColorLevels(int *pLimits, x::COLORREF *pColors, int nEntries)
 {
 #ifndef __SYSTRAY_DISABLED__
     for (int i = 0 ; i < nEntries ; i++)
