@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -335,7 +335,7 @@ wxUint32 hostip, wxUint16 port)
     case OP_GLOBFOUNDSOURCES:
         {
             theApp.downloadqueue->AddDownDataOverheadOther(size);
-            CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+            CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
             // process all source packets
             int iLeft;
             do
@@ -428,7 +428,7 @@ wxUint32 hostip, wxUint16 port)
             theApp.downloadqueue->AddDownDataOverheadOther(size);
             if (!update)
             return true;
-            CSafeMemFile *srvinfo = new CSafeMemFile((BYTE *) packet, size);
+            CSafeMemFile *srvinfo = new CSafeMemFile((x::BYTE *) packet, size);
             wxUint16 stringlen;
             char *strName, *strDesc;
             srvinfo->Read( &stringlen, 2);
