@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -48,14 +48,14 @@ public:
 	void DnsLookupDone(struct sockaddr_in* addr);
 	//void	DnsLookupDone(WPARAM wp, LPARAM lp);
 protected:
-	void	AsyncResolveDNS(LPCTSTR lpszHostAddress, UINT nHostPort);
+	void	AsyncResolveDNS(x::LPCTSTR lpszHostAddress, x::UINT nHostPort);
 	//HANDLE	DnsTaskHandle;					// dns lookup handle
 	
  public:
 	virtual void OnReceive(int nErrorCode);
 private:
-	LPCTSTR m_lpszHostAddress;
-	UINT m_nHostPort;
+	x::LPCTSTR m_lpszHostAddress;
+	x::UINT m_nHostPort;
 	//HWND m_hWndResolveMessage;	// where to send WM_DNSRESOLVED
 	//SOCKADDR_IN m_SaveAddr;
 	struct sockaddr_in m_SaveAddr;
