@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -58,7 +58,7 @@ CBarShader CUpDownClient::s_UpStatusBar(16);
 
 void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
-    RECT gaprect;
+    x::RECT gaprect;
     gaprect.top = rect.y + 2;
     gaprect.bottom = (rect.y + rect.height) - 2;
     //rect->left;:
@@ -99,11 +99,11 @@ void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyre
 }
 
  /*
- COLORREF crBoth;
- COLORREF crNeither;
- COLORREF crClientOnly;
- COLORREF crPending;
- COLORREF crNextPending;
+ x::COLORREF crBoth;
+ x::COLORREF crNeither;
+ x::COLORREF crClientOnly;
+ x::COLORREF crPending;
+ x::COLORREF crNextPending;
  if(bFlat) {
  crBoth = RGB(0, 150, 0);
  crNeither = RGB(224, 224, 224);
@@ -382,7 +382,7 @@ void CUpDownClient::ProcessUpFileStatus(char *packet, uint32_t size)
     m_nUpPartCount = 0;
     if (size == 16)
     return;
-    CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
+    CSafeMemFile *data = new CSafeMemFile((x::BYTE *) packet, size);
     unsigned char cfilehash[16];
     data->Read(cfilehash, 16);
     CKnownFile *tempreqfile = theApp.sharedfiles->GetFileByID(cfilehash);
@@ -428,7 +428,7 @@ void CUpDownClient::ProcessUpFileStatus(char *packet, uint32_t size)
 void CUpDownClient::CreateStandartPackets(byte *data, uint32_t togo, Requested_Block_Struct *currentblock)
 {
     uint32_t nPacketSize;
-    CMemFile memfile((BYTE *) data, togo);
+    CMemFile memfile((x::BYTE *) data, togo);
     if (togo > 10240)
     nPacketSize = togo/ (uint32_t)(togo/10240);
     else
@@ -451,7 +451,7 @@ void CUpDownClient::CreateStandartPackets(byte *data, uint32_t togo, Requested_B
 
 void CUpDownClient::CreatePackedPackets(byte *data, uint32_t togo, Requested_Block_Struct *currentblock)
 {
-    BYTE *output = new BYTE[togo + 300];
+    x::BYTE *output = new x::BYTE[togo + 300];
     uLongf newsize = togo + 300;
     uint16_t result = compress2(output, &newsize, data, togo, 9);
     if (result != Z_OK || togo <= newsize)
