@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -423,8 +423,8 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
     //dc.SelectObject(GetFont());
     //COLORREF crOldTextColor = dc->GetTextColor();
     //COLORREF crOldBkColor = dc->GetBkColor();
-    RECT cur_rec;
-    //memcpy(&cur_rec,&lpDrawItemStruct->rcItem,sizeof(RECT));
+    x::RECT cur_rec;
+    //memcpy(&cur_rec,&lpDrawItemStruct->rcItem,sizeof(x::RECT));
     cur_rec.left = rect.x;
     cur_rec.top = rect.y;
     cur_rec.right = rect.x + rect.width;
@@ -494,7 +494,7 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                     // Added Thief icon [BlackRat]
                     if (client->thief)
                     image = 9;
-                    POINT point =
+                    x::POINT point =
                     {
                         cur_rec.left, cur_rec.top + 1
                                         };
