@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -57,7 +57,7 @@ XBMDraw::~XBMDraw()
     }
 }
 
-bool XBMDraw::CreateImage(wxString sName, int nWidth, int nHeight, BYTE bBackground)
+bool XBMDraw::CreateImage(wxString sName, int nWidth, int nHeight, x::BYTE bBackground)
 {
     try
     {
@@ -66,7 +66,7 @@ bool XBMDraw::CreateImage(wxString sName, int nWidth, int nHeight, BYTE bBackgro
         m_nHeight = nHeight;
         if (m_pImage)
         delete[] m_pImage;
-        m_pImage = new BYTE[m_nWidth *m_nHeight];
+        m_pImage = new x::BYTE[m_nWidth *m_nHeight];
         memset(m_pImage, bBackground, m_nWidth *m_nHeight);
         return true;
     }
@@ -86,7 +86,7 @@ bool XBMDraw::GetImage(wxString &sImage)
             if (m_nWidth % 8 != 0)
             nRealWidth++;
             long nSize = nRealWidth *m_nHeight *6 + 1;
-            BYTE *sBits = new BYTE[nSize];
+            x::BYTE *sBits = new x::BYTE[nSize];
             memset(sBits, 0, nSize);
             int nCount = 0;
             for (int i = 0 ; i < nRealWidth *m_nHeight ; i++)
@@ -130,7 +130,7 @@ bool XBMDraw::Plot(int x, int y, bool bXOR)
                 if (m_nWidth % 8 != 0)
                 nRealWidth++;
                 int nPos = nRealWidth * (m_nHeight - y - 1) + (x / 8);
-                BYTE nVal = 1 << (x % 8);
+                x::BYTE nVal = 1 << (x % 8);
                 if (m_pImage[nPos] &nVal &&bXOR)
                 m_pImage[nPos] &= (0xff &~nVal);
                 else
