@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -35,14 +35,14 @@ public:
 	wxString GetImageTag();
 	bool Plot(int x, int y, bool bXOR = false);
 	bool GetImage(wxString &sImage);
-	bool CreateImage(wxString sName, int nWidth, int nHeight, BYTE bBackground = 0x00);
+	bool CreateImage(wxString sName, int nWidth, int nHeight, x::BYTE bBackground = 0x00);
 	XBMDraw();
 	virtual ~XBMDraw();
 private:
 	wxString	m_sName;
 	int		m_nWidth;
 	int		m_nHeight;
-	BYTE*	m_pImage;
+	x::BYTE*	m_pImage;
 };
 
 #endif // !defined(AFX_XBMDRAW_H__79B4E994_2752_4A68_A15E_29B04736D719__INCLUDED_)
