@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 #	include "CMemFile.h"
 #endif
 
-#include "wintypes.h"                       // BYTE - audited 4 Nov 2004
+#include "wintypes.h"                       // x::BYTE - audited 4 Nov 2004
 
 CMemFile::CMemFile(unsigned int growBytes)
 {
@@ -36,7 +36,7 @@ CMemFile::CMemFile(unsigned int growBytes)
     deleteBuffer = TRUE;
 }
 
-CMemFile::CMemFile(BYTE *buffer, unsigned int bufferSize, unsigned int growBytes)
+CMemFile::CMemFile(x::BYTE *buffer, unsigned int bufferSize, unsigned int growBytes)
 {
     fBufferSize = bufferSize;
     fPosition = 0;
@@ -48,7 +48,7 @@ CMemFile::CMemFile(BYTE *buffer, unsigned int bufferSize, unsigned int growBytes
     deleteBuffer = FALSE;
 }
 
-void CMemFile::Attach(BYTE *buffer, unsigned int bufferSize, unsigned int growBytes)
+void CMemFile::Attach(x::BYTE *buffer, unsigned int bufferSize, unsigned int growBytes)
 {
     fBufferSize = bufferSize;
     fPosition = 0;
@@ -60,9 +60,9 @@ void CMemFile::Attach(BYTE *buffer, unsigned int bufferSize, unsigned int growBy
     deleteBuffer = FALSE;
 }
 
-BYTE *CMemFile::Detach()
+x::BYTE *CMemFile::Detach()
 {
-    BYTE *retval = fBuffer;
+    x::BYTE *retval = fBuffer;
     fBuffer = NULL;
     fFileSize = fBufferSize = fPosition = fFileSize = 0;
     return retval;
@@ -109,8 +109,8 @@ void CMemFile::enlargeBuffer(unsigned long size)
     while (newsize < size)
     newsize += fGrowBytes;
     if (fBuffer)
-    fBuffer = (BYTE *) realloc((void *) fBuffer, newsize);
-    else fBuffer = (BYTE *) malloc(newsize);
+    fBuffer = (x::BYTE *) realloc((void *) fBuffer, newsize);
+    else fBuffer = (x::BYTE *) malloc(newsize);
     if (fBuffer == NULL)
     {
         // jaa-a. mithn tekis
