@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -51,42 +51,8 @@ static char THIS_FILE[] = __FILE__;
 // to avoid storing in the windows-directory
     /*static*/
 
-    void CIni::AddModulPath(wxString &strFileName, bool bModulPath /*= TRUE*/
-
-)
+void CIni::AddModulPath(wxString &strFileName, bool bModulPath)
 {
-#if 0
-    char drive[_MAX_DRIVE];
-    char dir[_MAX_DIR];
-    char fname[_MAX_FNAME];
-    char ext[_MAX_EXT];
-    _splitpath(strFileName, drive, dir, fname, ext);
-    if (! drive[0])
-    {
-        //PathCanonicalize(..) doesn't work with for all Plattforms !
-        wxString strModule;
-        if (bModulPath)
-        {
-            GetModuleFileName(NULL, strModule.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
-            strModule.ReleaseBuffer();
-        }
-        else
-        {
-            GetCurrentDirectory(MAX_INI_BUFFER, strModule.GetBuffer(MAX_INI_BUFFER));
-            strModule.ReleaseBuffer();
-            // fix by "cpp@world-online.no"
-            strModule.TrimRight('\\');
-            strModule.TrimRight('/');
-            strModule += "\\";
-        }
-        strModule.ReleaseBuffer();
-        _splitpath(strModule, drive, dir, fname, ext);
-        strModule = drive;
-        strModule += dir;
-        strModule += strFileName;
-        strFileName = strModule;
-    }
-#endif
 }
 
     /*static*/
@@ -103,37 +69,6 @@ wxString CIni::GetDefaultSection()
 
 )
 {
-#if 0
-    char drive[_MAX_DRIVE];
-    char dir[_MAX_DIR];
-    char fname[_MAX_FNAME];
-    char ext[_MAX_EXT];
-    wxString strTemp;
-    wxString strApplName;
-    GetModuleFileName(NULL, strTemp.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
-    strTemp.ReleaseBuffer();
-    _splitpath(strTemp, drive, dir, fname, ext);
-    //"ApplName":
-    strTemp = fname;
-    //"ApplName.ini":
-    strTemp += ".ini";
-    if (bModulPath)
-    {
-        strApplName = drive;
-        strApplName += dir;
-        strApplName += strTemp;
-    }
-    else
-    {
-        GetCurrentDirectory(MAX_INI_BUFFER, strApplName.GetBuffer(MAX_INI_BUFFER));
-        strApplName.ReleaseBuffer();
-        strApplName.TrimRight('\\');
-        strApplName.TrimRight('/');
-        strApplName += "\\";
-        strApplName += strTemp;
-    }
-    return strApplName;
-#endif
     return "perse";
 }
 
@@ -222,7 +157,7 @@ wxString const &CIni::GetSection() const
 //
 //////////////////////////////////////////////////////////////////////
 
-    void CIni::Init(LPCSTR strFileName, LPCSTR strSection/* = NULL*/
+    void CIni::Init(x::LPCSTR strFileName, x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -232,9 +167,9 @@ wxString const &CIni::GetSection() const
     m_strFileName = strFileName;
 }
 
-    wxString CIni::GetString(wxString strEntry, LPCSTR strDefault/*=NULL*/
+    wxString CIni::GetString(wxString strEntry, x::LPCSTR strDefault/*=NULL*/
 
-    , LPCSTR strSection/* = NULL*/
+    , x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -246,7 +181,7 @@ wxString const &CIni::GetSection() const
 
     double CIni::GetDouble(wxString strEntry, double fDefault/* = 0.0*/
 
-    , LPCSTR strSection/* = NULL*/
+    , x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -259,7 +194,7 @@ wxString const &CIni::GetSection() const
 
     float CIni::GetFloat(wxString strEntry, float fDefault/* = 0.0*/
 
-    , LPCSTR strSection/* = NULL*/
+    , x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -272,7 +207,7 @@ wxString const &CIni::GetSection() const
 
     int CIni::GetInt(wxString strEntry, int nDefault/* = 0*/
 
-    , LPCSTR strSection/* = NULL*/
+    , x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -283,9 +218,9 @@ wxString const &CIni::GetSection() const
     return atoi(m_chBuffer);
 }
 
-    WORD CIni::GetWORD(wxString strEntry, WORD nDefault/* = 0*/
+    x::WORD CIni::GetWORD(wxString strEntry, x::WORD nDefault/* = 0*/
 
-    , LPCSTR strSection/* = NULL*/
+    , x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -293,12 +228,12 @@ wxString const &CIni::GetSection() const
     //strDefault.Printf("%u",nDefault);
     strDefault = wxString::Format("%u", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
-    return(WORD) atoi(m_chBuffer);
+    return(x::WORD) atoi(m_chBuffer);
 }
 
     bool CIni::GetBool(wxString strEntry, bool bDefault/* = FALSE*/
 
-    , LPCSTR strSection/* = NULL*/
+    , x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -309,7 +244,7 @@ wxString const &CIni::GetSection() const
     return(atoi(m_chBuffer) != 0);
 }
 
-wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
+wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, x::LPCSTR strSection)
 {
     wxPoint ptReturn = ptDefault;
     wxString strDefault;
@@ -320,26 +255,12 @@ wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
     return ptReturn;
 }
 
-wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
+wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, x::LPCSTR strSection)
 {
-#if 0
-    wxRect rectReturn = rectDefault;
-    wxString strDefault;
-    //old version :strDefault.Printf("(%d,%d,%d,%d)",rectDefault.top,rectDefault.left,rectDefault.bottom,rectDefault.right);
-    strDefault.Printf("%d,%d,%d,%d", rectDefault.left, rectDefault.top, rectDefault.right, rectDefault.bottom);
-    wxString strRect = GetString(strEntry, strDefault);
-    int nRead = 0;
-    //new Version found
-    if (4 == sscanf(strRect, "%d,%d,%d,%d", &rectDefault.left, &rectDefault.top, &rectDefault.right, &rectDefault.bottom))
-    return rectReturn;
-    //old Version found
-    sscanf(strRect, "(%d,%d,%d,%d)", &rectReturn.top, &rectReturn.left, &rectReturn.bottom, &rectReturn.right);
-    return rectReturn;
-#endif
     return wxRect(0, 0, 0, 0);
 }
 
-COLORREF CIni::GetColRef(wxString strEntry, COLORREF crDefault, LPCSTR strSection)
+x::COLORREF CIni::GetColRef(wxString strEntry, x::COLORREF crDefault, x::LPCSTR strSection)
 {
     int temp[3] =
     {
@@ -363,7 +284,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     cb->Flush();
 }
 
-    void CIni::WriteString(wxString strEntry, wxString str, LPCSTR strSection/* = NULL*/
+    void CIni::WriteString(wxString strEntry, wxString str, x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -372,7 +293,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, str, m_strFileName);
 }
 
-    void CIni::WriteDouble(wxString strEntry, double f, LPCSTR strSection/*= NULL*/
+    void CIni::WriteDouble(wxString strEntry, double f, x::LPCSTR strSection/*= NULL*/
 
 )
 {
@@ -383,7 +304,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni::WriteFloat(wxString strEntry, float f, LPCSTR strSection/* = NULL*/
+    void CIni::WriteFloat(wxString strEntry, float f, x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -394,7 +315,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni::WriteInt(wxString strEntry, int n, LPCSTR strSection/* = NULL*/
+    void CIni::WriteInt(wxString strEntry, int n, x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -405,7 +326,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni::WriteWORD(wxString strEntry, WORD n, LPCSTR strSection/* = NULL*/
+    void CIni::WriteWORD(wxString strEntry, x::WORD n, x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -416,7 +337,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni::WriteBool(wxString strEntry, bool b, LPCSTR strSection/* = NULL*/
+    void CIni::WriteBool(wxString strEntry, bool b, x::LPCSTR strSection/* = NULL*/
 
 )
 {
@@ -427,7 +348,7 @@ void WritePrivateProfileString(const char *sec, const char *entry, const char *j
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-void CIni::WritePoint(wxString strEntry, wxPoint pt, LPCSTR strSection)
+void CIni::WritePoint(wxString strEntry, wxPoint pt, x::LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
@@ -436,7 +357,7 @@ void CIni::WritePoint(wxString strEntry, wxPoint pt, LPCSTR strSection)
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-void CIni::WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
+void CIni::WriteRect(wxString strEntry, wxRect rect, x::LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
@@ -445,7 +366,7 @@ void CIni::WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-void CIni::WriteColRef(wxString strEntry, COLORREF cr, LPCSTR strSection)
+void CIni::WriteColRef(wxString strEntry, x::COLORREF cr, x::LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
@@ -475,11 +396,11 @@ wxChar *CIni::GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxCha
     else
     temp = Read(m_strFileName, m_strSection, strEntry, strDefault);
     // '+1' damit die Null am Ende mit kopiert wird:
-    return(wxChar *) memcpy(m_chBuffer, (LPCTSTR) temp.GetData(), temp.Length() + 1);
+    return(wxChar *) memcpy(m_chBuffer, (x::LPCTSTR) temp.GetData(), temp.Length() + 1);
 #endif
 }
 
-void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
+void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, x::LPCSTR strSection, x::LPCSTR strDefault)
 {
     if (bGet)
     str = GetString(strEntry, strDefault/*=NULL*/
@@ -490,7 +411,7 @@ void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetDouble(bool bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDouble(bool bGet, double &f, wxString strEntry, x::LPCSTR strSection/* = NULL*/
 
     , double fDefault/* = 0.0*/
 
@@ -505,7 +426,7 @@ void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetFloat(bool bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetFloat(bool bGet, float &f, wxString strEntry, x::LPCSTR strSection/* = NULL*/
 
     , float fDefault/* = 0.0*/
 
@@ -520,7 +441,7 @@ void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetInt(bool bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetInt(bool bGet, int &n, wxString strEntry, x::LPCSTR strSection/* = NULL*/
 
     , int nDefault/* = 0*/
 
@@ -535,14 +456,14 @@ void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetDWORD(bool bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDWORD(bool bGet, x::DWORD &n, wxString strEntry, x::LPCSTR strSection/* = NULL*/
 
-    , DWORD nDefault/* = 0*/
+    , x::DWORD nDefault/* = 0*/
 
 )
 {
     if (bGet)
-    n = (DWORD) GetInt(strEntry, nDefault/*=NULL*/
+    n = (x::DWORD) GetInt(strEntry, nDefault/*=NULL*/
     , strSection/* = NULL*/
     );
     else
@@ -550,7 +471,7 @@ void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-    void CIni::SerGetBool(bool bGet, bool &b, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetBool(bool bGet, bool &b, wxString strEntry, x::LPCSTR strSection/* = NULL*/
 
     , bool bDefault/* = FALSE*/
 
@@ -565,7 +486,7 @@ void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strS
     );
 }
 
-void CIni::SerGetPoint(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault)
+void CIni::SerGetPoint(bool bGet, wxPoint &pt, wxString strEntry, x::LPCSTR strSection, wxPoint ptDefault)
 {
     if (bGet)
     pt = GetPoint(strEntry, ptDefault, strSection);
@@ -573,7 +494,7 @@ void CIni::SerGetPoint(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSect
     WritePoint(strEntry, pt, strSection);
 }
 
-void CIni::SerGetRect(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault)
+void CIni::SerGetRect(bool bGet, wxRect &rect, wxString strEntry, x::LPCSTR strSection, wxRect rectDefault)
 {
     if (bGet)
     rect = GetRect(strEntry, rectDefault, strSection);
@@ -581,7 +502,7 @@ void CIni::SerGetRect(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSect
     WriteRect(strEntry, rect, strSection);
 }
 
-void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault)
+void CIni::SerGetColRef(bool bGet, x::COLORREF &cr, wxString strEntry, x::LPCSTR strSection, x::COLORREF crDefault)
 {
     if (bGet)
     cr = GetColRef(strEntry, crDefault, strSection);
@@ -591,16 +512,16 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
 
 // berladene Methoden //////////////////////////////////////////////////////////////////////////////////////////////////77
 // Einfache Typen /////////////////////////////////////////////////////////////////////////////////////////////////////////
-    void CIni::SerGet(bool bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, wxString &str, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
-    , LPCSTR strDefault/*= NULL*/
+    , x::LPCSTR strDefault/*= NULL*/
 
 )
 {
     SerGetString(bGet, str, strEntry, strSection, strDefault);
 }
 
-    void CIni::SerGet(bool bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, double &f, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
     , double fDefault/* = 0.0*/
 
@@ -609,7 +530,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetDouble(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni::SerGet(bool bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, float &f, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
     , float fDefault/* = 0.0*/
 
@@ -618,7 +539,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetFloat(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni::SerGet(bool bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, int &n, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
@@ -627,7 +548,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetInt(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni::SerGet(bool bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, short &n, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
@@ -638,28 +559,28 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     n = nTemp;
 }
 
-    void CIni::SerGet(bool bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, x::DWORD &n, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
-    , DWORD nDefault/* = 0*/
+    , x::DWORD nDefault/* = 0*/
 
 )
 {
     SerGetDWORD(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni::SerGet(bool bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, x::WORD &n, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
-    , DWORD nDefault/* = 0*/
+    , x::DWORD nDefault/* = 0*/
 
 )
 {
-    DWORD dwTemp = n;
+    x::DWORD dwTemp = n;
     SerGetDWORD(bGet, dwTemp, strEntry, strSection, nDefault);
     n = dwTemp;
 }
 
-//	void		SerGet(	bool bGet,bool		& b,	wxString strEntry,	LPCSTR strSection = NULL,	bool bDefault = FALSE);
-    void CIni::SerGet(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
+//	void		SerGet(	bool bGet,bool		& b,	wxString strEntry,	x::LPCSTR strSection = NULL,	bool bDefault = FALSE);
+    void CIni::SerGet(bool bGet, wxPoint &pt, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
     , wxPoint ptDefault/* = wxPoint(0,0)*/
 
@@ -668,7 +589,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetPoint(bGet, pt, strEntry, strSection, ptDefault);
 }
 
-    void CIni::SerGet(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, wxRect &rect, wxString strEntry, x::LPCSTR strSection/*= NULL*/
 
     , wxRect rectDefault/* = wxRect(0,0,0,0)*/
 
@@ -677,14 +598,14 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     SerGetRect(bGet, rect, strEntry, strSection, rectDefault);
 }
 
-//	void		SerGet(	bool bGet,COLORREF	& cr,	wxString strEntry,	LPCSTR strSection = NULL,	COLORREF crDefault = RGB(128,128,128));
+//	void		SerGet(	bool bGet,x::COLORREF	& cr,	wxString strEntry,	x::LPCSTR strSection = NULL,	x::COLORREF crDefault = RGB(128,128,128));
 
 // berladene Methoden ////////////////////////////////////////////////////////////////////////////////////////////
 // ARRAYS /////////////////////////////////////////////////////////////////////////////////////////////////////////
 // Entries werden durch Unterstrich + Index ergenzt////////////////////////////////////////////////////////////////
-    void CIni::SerGet(bool bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxString *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
-    , LPCSTR Default/*=NULL*/
+    , x::LPCSTR Default/*=NULL*/
 
 )
 {
@@ -716,7 +637,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, double *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , double Default/* = 0.0*/
 
@@ -755,7 +676,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, float *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , float Default/* = 0.0*/
 
@@ -794,7 +715,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, int *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
@@ -833,7 +754,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, unsigned char *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , unsigned char Default/* = 0*/
 
@@ -872,7 +793,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, short *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
@@ -911,9 +832,9 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, x::DWORD *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
-    , DWORD Default/* = 0*/
+    , x::DWORD Default/* = 0*/
 
 )
 {
@@ -931,7 +852,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
                 if (strTemp.Length() == 0)
                 ar[i] = Default;
                 else
-                ar[i] = (DWORD) atoi(strTemp);
+                ar[i] = (x::DWORD) atoi(strTemp);
             }
         }
         else
@@ -950,9 +871,9 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, x::WORD *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
-    , DWORD Default/* = 0*/
+    , x::DWORD Default/* = 0*/
 
 )
 {
@@ -970,7 +891,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
                 if (strTemp.Length() == 0)
                 ar[i] = Default;
                 else
-                ar[i] = (WORD) atoi(strTemp);
+                ar[i] = (x::WORD) atoi(strTemp);
             }
         }
         else
@@ -989,7 +910,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxPoint *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , wxPoint Default/* = wxPoint(0,0)*/
 
@@ -1004,7 +925,7 @@ void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSe
     }
 }
 
-    void CIni::SerGet(bool bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxRect *ar, int nCount, wxString strEntry, x::LPCSTR strSection/*=NULL*/
 
     , wxRect Default/* = wxRect(0,0,0,0)*/
 
