@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     04.12.99
-// RCS-ID:      $Id: listbase.h,v 1.12 2004/08/23 05:53:30 HopeSeekr Exp $
+// RCS-ID:      $Id: listbase.h,v 1.14 2005/05/13 19:24:14 hopeseekr Exp $
 // Copyright:   (c) wxWindows team
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -37,9 +37,8 @@
 
 #if wxUSE_LISTCTRL
 
-#include <wx/colour.h>
-#include <wx/font.h>
-
+#include <wx/colour.h>                      // wxColour
+#include <wx/font.h>                        // wxFont
 // ----------------------------------------------------------------------------
 // types
 // ----------------------------------------------------------------------------
@@ -402,7 +401,7 @@ public:
     int GetCode() const { return GetKeyCode(); }
 #endif // WXWIN_COMPATIBILITY_2_2
 
-    virtual wxCommandEvent *Clone() const { return new wxListEvent(*this); }
+    virtual wxEvent *Clone() const { return new wxListEvent(*this); }
 
 //protected: -- not for backwards compatibility
     int           m_code;
@@ -440,7 +439,7 @@ BEGIN_DECLARE_EVENT_TYPES()
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_ITEM_ACTIVATED, 715)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_CACHE_HINT, 716)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_RIGHT_CLICK, 717)
-        DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_MIDDLE_CLICK, 718)
+	DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_MIDDLE_CLICK, 718)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_BEGIN_DRAG, 719)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_DRAGGING, 720)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_END_DRAG, 721)
