@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -26,7 +26,7 @@
 #	include "PartFile.h"
 #	include "Preferences.h"                 // CPreferences::GetAllinCat
 #	include "resource.h"
-#	include "wintypes.h"                    // BYTE DWORD UINT WORD
+#	include "wintypes.h"                    // x::BYTE x::DWORD x::UINT WORD
 #	include "xmule.h"
 #endif
 
@@ -56,12 +56,12 @@ wxString GetResString(unsigned int uStringID)
 }
 
 // Base chars for encode an decode functions
-static BYTE base16Chars[17] = "0123456789ABCDEF";
+static x::BYTE base16Chars[17] = "0123456789ABCDEF";
 
-static BYTE base32Chars[33] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
+static x::BYTE base32Chars[33] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
 
 #define BASE16_LOOKUP_MAX 23
-static BYTE base16Lookup[BASE16_LOOKUP_MAX][2] =
+static x::BYTE base16Lookup[BASE16_LOOKUP_MAX][2] =
 {
     {
         '0', 0x0
@@ -330,14 +330,14 @@ wxString URLEncode(wxString sIn)
 {
     wxString sOut;
     const int nLen = sIn.Length() + 1;
-    register LPBYTE pOutTmp = NULL;
-    LPBYTE pOutBuf = NULL;
-    register LPBYTE pInTmp = NULL;
+    register x::LPBYTE pOutTmp = NULL;
+    x::LPBYTE pOutBuf = NULL;
+    register x::LPBYTE pInTmp = NULL;
     //GetData(); //GetBuffer(nLen);:
-    LPBYTE pInBuf = (LPBYTE) sIn.GetWriteBuf(nLen);
+    x::LPBYTE pInBuf = (x::LPBYTE) sIn.GetWriteBuf(nLen);
     //alloc out buffer
-    //GetData(); //GetBuffer(nLen  * 3 - 2);//new BYTE [nLen  * 3];:
-    pOutBuf = (LPBYTE) sOut.GetWriteBuf(nLen *3 - 2);
+    //GetData(); //GetBuffer(nLen  * 3 - 2);//new x::BYTE [nLen  * 3];:
+    pOutBuf = (x::LPBYTE) sOut.GetWriteBuf(nLen *3 - 2);
     if (pOutBuf)
     {
         pInTmp = pInBuf;
@@ -491,7 +491,7 @@ bool Ask4RegFix(bool checkOnly)
     // check registry if ed2k links is assigned to xmule
     CRegKey regkey;
     regkey.Create(HKEY_CLASSES_ROOT, "ed2k\\shell\\open\\command");
-    ULONG maxsize = 500;
+    x::ULONG maxsize = 500;
     TCHAR rbuffer[500];
     char modbuffer[490];
     char regbuffer[520];
@@ -542,13 +542,13 @@ int GetMaxConnections()
         {
             //old school 95
             HKEY hKey;
-            DWORD dwValue;
-            DWORD dwLength = sizeof(dwValue);
-            LONG lResult;
+            x::DWORD dwValue;
+            x::DWORD dwLength = sizeof(dwValue);
+            x::LONG lResult;
             RegOpenKeyEx(HKEY_LOCAL_MACHINE, "System\\CurrentControlSet\\Services\\VxD\\MSTCP",
             0, KEY_QUERY_VALUE, &hKey);
             lResult = RegQueryValueEx(hKey, TEXT("MaxConnections"), NULL, NULL,
-            (LPBYTE) &dwValue, &dwLength);
+            (x::LPBYTE) &dwValue, &dwLength);
             RegCloseKey(hKey);
             if (lResult != ERROR_SUCCESS || lResult < 1)
             //the default for 95 is 100:
@@ -560,14 +560,14 @@ int GetMaxConnections()
             //98 or ME
             HKEY hKey;
             TCHAR szValue[32];
-            DWORD dwLength = sizeof(szValue);
-            LONG lResult;
+            x::DWORD dwLength = sizeof(szValue);
+            x::LONG lResult;
             RegOpenKeyEx(HKEY_LOCAL_MACHINE, "System\\CurrentControlSet\\Services\\VxD\\MSTCP",
             0, KEY_QUERY_VALUE, &hKey);
             lResult = RegQueryValueEx(hKey, TEXT("MaxConnections"), NULL, NULL,
-            (LPBYTE) szValue, &dwLength);
+            (x::LPBYTE) szValue, &dwLength);
             RegCloseKey(hKey);
-            LONG lMaxConnections;
+            x::LONG lMaxConnections;
             if (lResult != ERROR_SUCCESS || (lMaxConnections = atoi(szValue)) < 1)
             //the default for 98/ME is 100:
             return 100;
@@ -606,14 +606,14 @@ wxString GetRateString(uint16_t rate)
     return GetResString(IDS_CMT_NOTRATED);
 }
 
-// Returns a BASE32 encoded BYTE array
+// Returns a BASE32 encoded x::BYTE array
 //
 // [In]
-//   buffer: Pointer to BYTE array
+//   buffer: Pointer to x::BYTE array
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   wxString object with BASE32 encoded BYTE array
+//   wxString object with BASE32 encoded x::BYTE array
 wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
 {
     wxString Base32Buff;
@@ -622,7 +622,7 @@ wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
 
     for (i = 0, index = 0 ; i < bufLen ;)
     {
-        // Is the current word going to span a BYTE boundary?
+        // Is the current word going to span a x::BYTE boundary?
         if (index > 3)
         {
             word = (buffer[i] & (0xFF >> index));
@@ -652,14 +652,14 @@ wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
     return Base32Buff;
 }
 
-// Returns a BASE16 encoded BYTE array
+// Returns a BASE16 encoded x::BYTE array
 //
 // [In]
-//   buffer: Pointer to BYTE array
+//   buffer: Pointer to x::BYTE array
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   wxString object with BASE16 encoded BYTE array
+//   wxString object with BASE16 encoded x::BYTE array
 wxString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
 {
     wxString Base16Buff;
@@ -673,22 +673,22 @@ wxString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
     return Base16Buff;
 }
 
-// Decodes a BASE16 string into a BYTE array
+// Decodes a BASE16 string into a x::BYTE array
 //
 // [In]
 //   base16Buffer: String containing BASE16
 //   base16BufLen: Lenght BASE16 coded string's length
 //
 // [Out]
-//   buffer: BYTE array containing decoded string
-void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, BYTE *buffer)
+//   buffer: x::BYTE array containing decoded string
+void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, x::BYTE *buffer)
 {
     memset(buffer, 0, DecodeLengthBase16(base16BufLen));
     for (unsigned int i = 0 ; i < base16BufLen ; i++)
     {
         int lookup = toupper(base16Buffer[i]) - '0';
         // Check to make sure that the given word falls inside a valid range
-        BYTE word = 0;
+        x::BYTE word = 0;
         if (lookup < 0 || lookup >= BASE16_LOOKUP_MAX)
         word = 0xFF;
         else
@@ -710,7 +710,7 @@ void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, BYTE *buf
 //   base16Length: Actual length of BASE16 string
 //
 // [Return]
-//   New length of BYTE array decoded
+//   New length of x::BYTE array decoded
 int DecodeLengthBase16(int base16Length)
 {
     return base16Length / 2;
