@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -200,7 +200,7 @@ Packet::Packet(CMemFile* datafile, const uint8_t protocol)
     size = datafile->GetLength();
     my->completebuffer = new char[datafile->GetLength() + 10];
     pBuffer = my->completebuffer + 6;
-    BYTE* tmp = datafile->Detach();;
+    x::BYTE* tmp = datafile->Detach();;
     memcpy(pBuffer, tmp, size);
     free(tmp);
     my->tempbuffer = 0;
@@ -319,9 +319,9 @@ char* Packet::GetUDPHeader()
 void Packet::PackPacket()
 {
     assert(!my->bSplitted);
-    BYTE* output = new BYTE[size + 300];
+    x::BYTE* output = new x::BYTE[size + 300];
     uLongf newsize(size + 300);
-    uint16_t result(compress2(output, &newsize, (BYTE *) pBuffer, size, Z_BEST_COMPRESSION));
+    uint16_t result(compress2(output, &newsize, (x::BYTE *) pBuffer, size, Z_BEST_COMPRESSION));
 
     if (result != Z_OK || size <= newsize)
     {
@@ -335,7 +335,7 @@ void Packet::PackPacket()
     my->bPacked = true;
 }
 
-bool Packet::UnPackPacket(UINT uMaxDecompressedSize)
+bool Packet::UnPackPacket(x::UINT uMaxDecompressedSize)
 {
     assert(prot == OP_PACKEDPROT);
     uint32_t nNewSize(size *10 + 300);
@@ -345,9 +345,9 @@ bool Packet::UnPackPacket(UINT uMaxDecompressedSize)
         nNewSize = uMaxDecompressedSize;
     }
 
-    BYTE* unpack = new BYTE[nNewSize];
+    x::BYTE* unpack = new x::BYTE[nNewSize];
     uLongf unpackedsize(nNewSize);
-    uint16_t result(uncompress(unpack, &unpackedsize, (BYTE *) pBuffer, size));
+    uint16_t result(uncompress(unpack, &unpackedsize, (x::BYTE *) pBuffer, size));
     
     if (result == Z_OK)
     {
