@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -23,7 +23,7 @@
 #define PACKETS_H
 
 #include "opcodes.h"                        // OP_EDONKEYPROT - audited 5 Nov 2004
-#include "wintypes.h"                       // UINT - audited 4 Nov 2004
+#include "wintypes.h"                       // x::UINT - audited 4 Nov 2004
 
 #include <cstdio>                           // FILE
 #include <exception>                        // std::exception
@@ -59,7 +59,7 @@ public:
     bool IsSplitted() const;
     bool IsLastSplitted() const;
     void    PackPacket();
-    bool    UnPackPacket(UINT uMaxDecompressedSize = 50000);
+    bool    UnPackPacket(x::UINT uMaxDecompressedSize = 50000);
     char*   pBuffer;
     uint32_t  size;
     uint8_t   opcode;
