@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 //{{NO_DEPENDENCIES}}
 // Microsoft Visual C++ generated include file.
 // Used by xmule.rc
-
+//
 #define IDR_MANIFEST                    1
 #define IDC_BUTTONRENAME                2
 #define IDC_BUTTONSTRIP                 3
@@ -59,11 +59,15 @@
 #define IDS_HTTPDOWNLOAD_BYTESPERSECOND 128
 #define IDR_MAINFRAME                   129
 #define IDS_HTTPDOWNLOAD_KILOBYTESPERSECOND 129
+#define IDD_TRANSFER                    130
 #define IDS_HTTPDOWNLOAD_OK_TO_OVERWRITE 130
+#define IDD_SERVER                      131
 #define IDS_HTTPDOWNLOAD_FAIL_FILE_OPEN 131
 #define IDS_HTTPDOWNLOAD_ABORTING_TRANSFER 132
 #define IDD_TRANSFER1                   133
+#define IDD_FILES                       133
 #define IDS_MAIN_READY                  133
+#define IDD_SEARCH                      134
 #define IDD_SEARCHDLG                   134
 #define IDS_MAIN_SOCKETERROR            134
 #define IDS_MAIN_BTN_DISCONNECT         135
@@ -101,6 +105,7 @@
 #define IDS_ERR_FILEOPEN                152
 #define IDD_HTTPDOWNLOAD                153
 #define IDS_ERR_REHASH                  153
+#define IDD_CHAT                        154
 #define IDS_ERR_PART_FNF                154
 #define IDS_ERR_OPENMETFILE             155
 #define IDR_HTTPDOWNLOAD_ANIMATION      156
@@ -114,6 +119,7 @@
 #define IDS_ICHWORKED                   160
 #define IDI_CONNECTEDHIGH               161
 #define IDS_ERR_OUTOFSPACE              161
+#define IDD_SOURCEDETAILWND             162
 #define IDS_ERR_WRITEERROR              162
 #define IDI_COMPPROT                    163
 #define IDS_ERR_COMPLETIONFAILED        163
@@ -264,10 +270,15 @@
 #define IDS_SHAREDFILES                 288
 #define IDS_PRIOVERYLOW                 289
 #define IDS_PRIORELEASE                 290
+#define IDD_PPG_CONNECTION              290
 #define IDS_FSTATUS_LOCKED              291
+#define IDD_PPG_DIRECTORIES             291
 #define IDS_FSTATUS_FRIENDSONLY         292
+#define IDD_PPG_FILES                   292
 #define IDS_FSTATUS_PUBLIC              293
+#define IDD_PPG_GENERAL                 293
 #define IDS_PRIOHIGHEST                 294
+#define IDD_PPG_SERVER                  294
 #define IDS_ERR_NOPRIMCHANGE            295
 #define IDS_HIDDEN                      296
 #define IDS_FSTAT_TRANSFER              297
@@ -594,6 +605,7 @@
 #define IDS_STREE                       595
 #define IDD_STATSSETUP                  596
 #define IDS_STATSSETUPINFO              596
+#define IDD_PPG_STATS                   596
 #define IDS_HARDLIMIT                   597
 #define IDS_COL_MORECOLORS              598
 #define IDS_KBYTESEC                    599
@@ -734,7 +746,9 @@
 #define IDS_WIZARD_ENTERBELOW           719
 #define IDI_PREF_TWEAK                  719
 #define IDS_STATS_MAXAVGDL              720
+#define IDD_COMMENT                     720
 #define IDS_STATS_MAXDL                 721
+#define IDD_COMMENTLST                  721
 #define IDS_PW_FASTSRVCON               722
 #define IDS_SOURCELINKFAILED            723
 #define IDI_CLOSE                       723
@@ -1043,6 +1057,7 @@
 #define IDS_FILTER                      1005
 #define IDS_CHANGECATVIEW               1025
 #define IDS_STATUS_NOTCOMPLETED         1026
+#define IDD_FLOWCHART			1109
 #define IDC_ANIMATE1                    2000
 #define IDC_STATUS                      2001
 #define IDC_FILESTATUS                  2002
@@ -1086,6 +1101,7 @@
 #define IDC_LIST2                       2011
 #define IDC_DOWNLOADLIST                2011
 #define IDC_SBUTTON1                    2011
+//#define IDC_RELOADSHAREDFILES           2011
 #define IDC_BN_DOWNLOADS                2011
 #define IDC_MAXCON2                     2011
 #define IDC_TOOLTIPDELAY                2011
@@ -1097,6 +1113,7 @@
 #define IDC_ADD                         2011
 #define IDC_COLOR_BUTTON                2011
 #define IDC_EDITADR                     2011
+//#define IDC_BROWSE                      2011
 #define IDC_RELOADFILTER                2011
 #define IDC_HOTMENU                     2011
 #define IDC_WSRELOADTMPL                2011
@@ -1242,17 +1259,23 @@
 #define IDC_DNAME                       2074
 #define IDC_FSTATIC7                    2074
 #define IDC_DSOFT                       2075
+//#define IDC_SREQUESTED                  2075
 #define IDC_FSTATIC10                   2075
 #define IDC_NAME21                      2075
 #define IDC_DIP                         2076
+//#define IDC_SACCEPTED                   2076
 #define IDC_DSIP                        2077
+//#define IDC_STRANSFERED                 2077
 #define IDC_DHASH                       2078
 #define IDC_FSTATIC8                    2078
 #define IDC_DVERSION                    2079
 #define IDC_FSTATIC9                    2079
 #define IDC_DID                         2080
+//#define IDC_SREQUESTED2                 2080
 #define IDC_DSNAME                      2081
+//#define IDC_SACCEPTED2                  2081
 #define IDC_DDOWNLOADING                2082
+//#define IDC_STRANSFERED2                2082
 #define IDC_DDOWN                       2083
 #define IDC_DAVDR                       2084
 #define IDC_DDUP                        2085
@@ -1284,18 +1307,26 @@
 #define IDC_SLIDER                      2102
 #define IDC_FD_XI13                     2102
 #define IDC_BN_SEARCH                   2103
+//#define IDC_C1                          2103
 #define IDC_FD_XI6                      2103
 #define IDC_STATIC_LINE                 2104
 #define IDC_FD_XI8                      2104
 #define IDC_SLIDER_VALUE                2105
 #define IDC_FD_XI10                     2105
+//#define IDC_C0                          2106
 #define IDC_FD_XI12                     2106
 #define IDC_STATIC_D                    2107
 #define IDC_STATIC_U                    2108
 #define IDC_STATISTICS                  2109
 #define IDC_STATS                       2110
 #define IDC_STATSSCOPE                  2110
+//#define IDC_S0                          2111
+//#define IDC_S1                          2112
+//#define IDC_S3                          2113
+//#define IDC_S2                          2114
+#define IDD_STATISTICS                  2115
 #define IDC_STATIC7                     2115
+//#define IDC_C0_2                        2115
 #define IDC_STATIC_S0                   2116
 #define IDD_SPLASH                      2116
 #define IDC_STATIC_S1                   2117
@@ -1310,10 +1341,13 @@
 #define IDC_STATIC_U2                   2123
 #define IDC_STATIC_U3                   2124
 #define IDC_EXIT                        2124
+//#define IDC_C2                          2125
+//#define IDC_C1_2                        2125
 #define IDC_SPIN1                       2125
 #define IDC_SPLASHON                    2125
 #define IDC_FRAME2                      2126
 #define IDC_PUBLICSHARED                2126
+//#define IDC_C0_3                        2126
 #define IDC_FRAME1                      2127
 #define IDC_STATIC_D4                   2127
 #define IDC_TIMEAVG1                    2127
@@ -1323,6 +1357,7 @@
 #define IDC_TIMEAVG2                    2130
 #define IDC_CHECK2                      2131
 #define IDC_FILTER                      2131
+//#define IDC_C1_3                        2131
 #define IDC_IRC_USECHANFILTER           2131
 #define IDC_UDPDISABLE                  2131
 #define IDC_VERBOSE                     2131
@@ -1367,6 +1402,7 @@
 #define IDC_S_TITLE                     2167
 #define IDC_IRC_MISC_FRM                2168
 #define IDC_UDPPORTLABEL                2169
+#define IDC_CMSTATUS                    2170
 #define IDC_LANG                        2171
 #define IDC_LANG_FRM                    2172
 #define IDC_CONNTITLE                   2173
@@ -1481,13 +1517,16 @@
 #define IDC_SEEMYSHARE_FRM              2254
 #define IDC_MESSAGES_LBL                2255
 #define IDC_SETUPBUTTON                 2256
+#define IDD_PPG_NOTIFY                  2256
 #define IDC_SLIDERINFO3                 2257
 #define IDC_EDIT_TBN_WAVFILE            2257
+#define IDD_PPG_IRC                     2257
 #define IDC_GRAPHS                      2258
 #define IDC_CB_TBN_ONLOG                2258
 #define IDD_WIZARD                      2258
 #define IDC_STREE                       2259
 #define IDC_CB_TBN_POP_ALWAYS           2259
+#define IDD_PPG_TWEAKS                  2259
 #define IDC_KBS1                        2260
 #define IDD_ADDFRIEND                   2260
 #define IDC_KBS2                        2261
@@ -1517,18 +1556,22 @@
 #define IDC_WIZ_TRUEUPLOAD_BOX          2280
 #define IDC_UDPPORT                     2280
 #define IDC_USERNAME                    2280
+//#define IDC_CMT_TEXT                    2280
 #define IDC_MAXSRCPERFILESOFT           2280
 #define IDC_MAXSRCEPERFILESOFT          2280
 #define IDC_DEBUG_LOG                   2280
+//#define IDC_TITLE                       2280
 #define IDC_FILTERLEVEL                 2280
 #define IDC_TEXT                        2280
 #define IDC_WSPORT                      2280
 #define IDC_WIZARD                      2281
 #define IDC_USERHASH                    2281
+//#define IDC_INCOMING                    2281
 #define IDC_WSPASS                      2281
 #define IDC_OS_FRAME                    2282
 #define IDC_IP                          2282
 #define IDC_INCOMING2                   2282
+//#define IDC_COMMENT                     2282
 #define IDC_WSPASS2                     2282
 #define IDC_WSPASSLOW                   2282
 #define IDC_HOTBUTTON_FRAME             2283
@@ -1554,6 +1597,7 @@
 #define IDC_KBITS                       2303
 #define IDC_KBYTES                      2304
 #define IDC_FILEINFO                    2305
+//#define IDC_FILESIZE                    2306
 #define IDC_UNIT                        2307
 #define IDC_CTINFO                      2308
 #define IDC_MAXCONLABEL                 2310
@@ -1562,6 +1606,11 @@
 #define IDC_PWT_NETWORK                 2313
 #define IDC_INFO1                       2314
 #define IDC_INFO2                       2315
+#define IDCOK                           2316
+#define IDCCANCEL                       2317
+#define IDC_CMT_LQUEST                  2318
+#define IDC_CMT_LAIDE                   2319
+#define IDCREF                          2319
 #define IDC_RATEQUEST                   2320
 #define IDC_LST                         2320
 #define IDC_RATEHELP                    2321
@@ -1598,6 +1647,7 @@
 #define IDC_CLIENTLIST                  2354
 #define IDC_STATIC_FILTERLEVEL2         2354
 #define IDC_EDITFILTER                  2355
+//#define IDC_CATCOLOR                    2356
 #define IDC_FILTERCOMMENTSLABEL         2357
 #define IDC_WATCHCB                     2358
 #define IDC_STATIC_COLOR                2359
@@ -1670,11 +1720,13 @@
 #define IDI_ICON8                       2425
 #define IDI_PREF_DISPLAY                2426
 #define IDD_PPG_DISPLAY                 2427
+#define IDD_CAT                         2428
 #define IDR_TASKBAR                     2429
 #define IDI_PREF_SECURITY               2430
 #define IDD_PPG_SECURITY                2431
 #define IDC_IRC_EMULEPROTO_INFOMESSAGE  2432
 #define IDC_STATIC_PRIO                 2433
+//#define IDC_PRIOCOMBO                   2434
 #define IDR_WIZ1_WATERMARK              2435
 #define IDR_WIZ1_HEADER                 2436
 #define IDC_STARTNEXTFILECAT            2437
@@ -1705,6 +1757,8 @@
 
 #define ID_SOKETTI 7772
   
+#define IDD_PPG_SOURCES_DROPPING 12743
+#define IDD_PPG_GUI_TWEAKS 12744
 #define IDC_ENABLE_AUTO_NNS 12745
 #define IDC_AUTO_NNS_TIMER_TEXT 12746
 #define IDC_AUTO_NNS_TIMER 12747
@@ -1743,4 +1797,3 @@
 #define _APS_NEXT_SYMED_VALUE           106
 #endif
 #endif
-
