@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -368,8 +368,8 @@ void CServerConnect::ConnectionFailed(CServerSocket *sender)
 
 void CServerConnect::CheckForTimeout()
 {
-    DWORD maxage = GetTickCount() - CONSERVTIMEOUT;
-    DWORD tmpkey;
+    x::DWORD maxage = GetTickCount() - CONSERVTIMEOUT;
+    x::DWORD tmpkey;
     CServerSocket* tmpsock;
 
     map<uint32_t, CServerSocket *>::iterator it;
@@ -440,7 +440,7 @@ CServerConnect::CServerConnect(CServerList *in_serverlist, CPreferences *in_pref
 
 CServerConnect::~CServerConnect()
 {
-/*  K...I have *no* idea how this got here or what I was thinking...it causes crashes, so it's gone.
+/*  K...I have *no* idea how this got here or what I was thinking...it causes crashes, so it's gone.*/
     for (POSITION pos = m_lstOpenSockets.GetHeadPosition() ; pos != NULL ;)
     {
         CServerSocket* tmp((CServerSocket *)m_lstOpenSockets.GetNext(pos));
@@ -448,7 +448,7 @@ CServerConnect::~CServerConnect()
         tmp->Destroy();
         delete tmp;
     }
-*/
+
     m_idRetryTimer.Stop();
     StopConnectionTry();
     DestroySocket(connectedsocket);
