@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
@@ -23,7 +23,7 @@
 #define _UPDOWNCLIENT_H
 
 #include "mfc.h"                            // Needed for wxString - audited 4 Nov 2004
-#include "wintypes.h"                       // Needed for BYTE DWORD - audited 4 Nov 2004
+#include "wintypes.h"                       // Needed for x::BYTE x::DWORD - audited 4 Nov 2004
 #include "BarShader.h"                      // Needed for CBarShader - audited 5 Nov 2004
 
 #include <iostream>                         // Needed for std::cout std::endl
@@ -327,7 +327,7 @@ public:
     void			SetFileRate(int8_t iNewRate)	{m_iRate=iNewRate;}
 
 	// Barry - Process zip file as it arrives, don't need to wait until end of block
-	int unzip(Pending_Block_Struct *block, BYTE *zipped, uint32_t lenZipped, BYTE **unzipped, uint32_t *lenUnzipped, bool recursive = false);
+	int unzip(Pending_Block_Struct *block, x::BYTE *zipped, uint32_t lenZipped, x::BYTE **unzipped, uint32_t *lenUnzipped, bool recursive = false);
 	// Barry - Sets string to show parts downloading, eg NNNYNNNNYYNYN
 	void ShowDownloadingParts(wxString &partsYN);
 	void UpdateDisplayedInfo(bool force=false);
@@ -389,7 +389,7 @@ private:
 	
 	uint32_t	m_byCompatibleClient;
 	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
-	DWORD	m_lastRefreshedDLDisplay;
+	x::DWORD	m_lastRefreshedDLDisplay;
 
 	//upload
 	void CreateStandartPackets(byte* data,uint32_t togo, Requested_Block_Struct* currentblock);
@@ -413,7 +413,7 @@ private:
 	public:
 	uint8_t*		m_abyUpPartStatus;
 	uint16_t		m_lastPartAsked;
-	DWORD		m_dwEnteredConnectedState;
+	x::DWORD		m_dwEnteredConnectedState;
 	wxString		m_strModVersion;
 	uint32_t		m_nSumForAvgUpDataRate;
 
