@@ -1,6 +1,6 @@
 // This file is a part of the xMule Project.
 // 
-// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 // 
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
@@ -34,6 +34,7 @@
 #include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
 #include "FriendList.h"                     // Needed for CFriendList
+#include "ini2.h"                           // Needed for CIni
 #include "KnownFileList.h"                  // Needed for CKnownFileList
 #include "ldaemon.h"                        // Needed for CLDaemon
 #include "ListenSocket.h"                   // Needed for CListenSocket
@@ -178,6 +179,38 @@ wxCAPTION | wxRESIZE_BORDER | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxTHICK_FRAME
 
 void CxmuleDlg::OnInit()
 {
+    wxString full_path(getenv("HOME"), *wxConvCurrent);
+    full_path += "/";
+    CIni ini(full_path, "eMule");
+
+    theApp.dynprefs->Add("accept-license", ini.GetBool("AcceptLicense", false));
+
+    if (theApp.dynprefs->Get<bool>("accept-license") == false)
+    {
+        wxString accept_use;
+        accept_use  = "By clicking \"Yes\" below, you agree to not use xMule for any reasonably ";
+        accept_use += "illegal uses for your own country, unless the usage is for purely ";
+        accept_use += "political purposes (such as the dissemination of politically-explosive news or ";
+        accept_use += "ideology that would otherwise be suppressed by totalitarian regimes.\n\n";
+        accept_use += "Under no circumstances may this program be used to facilitate intellectual property theft, ";
+        accept_use += "and is only explicitly sanctioned for use in such endeavors as a) distributing one's own ";
+        accept_use += "intellectual property, b) distributing political and/or cultural currency (such as personal ";
+        accept_use += "artistic work), and c) the distribution of opensource software.\n\n";
+        accept_use += "All attempts to reverse-engineer this software (including but not limited to taking more than ";
+        accept_use += "1% of its freely-available source code for use in another product) are restricted, in order ";
+        accept_use += "to be fully compliant with the DMCA (USA) and WTO-WIPO (world) laws and treaties.\n\n";
+        accept_use += "Do you accept the xMule License?";
+        wxMessageDialog msg(NULL, accept_use, "xMule Acceptable Use License", wxYES_NO | wxNO_DEFAULT | wxICON_QUESTION);
+
+        if (msg.ShowModal() == wxID_NO)
+        {
+           exit(1);
+        }
+
+        theApp.dynprefs->Add("accept-license", true);
+        ini.WriteBool("AcceptLicense", theApp.dynprefs->Get<bool>("accept-license"));
+    }
+
     theApp.xmuledlg = this;
     m_app_state = APP_STATE_STARTING;
     srand(time(NULL));
@@ -888,7 +921,7 @@ void CxmuleDlg::UpdateTrayIcon(int procent)
         100
         };
     // set the corresponding color for each level
-    COLORREF pColors16[1] =
+    x::COLORREF pColors16[1] =
     {
         theApp.glob_prefs->GetStatsColor(11)
         };
